@@ -129,6 +129,8 @@ QString RequestKey(Types &&...values) {
 	return result;
 }
 
+[[nodiscard]] TimeId UnixtimeFromMsgId(mtpMsgId msgId);
+
 } // namespace Api
 
 class ApiWrap final : public MTP::Sender {
@@ -363,7 +365,9 @@ public:
 	void sendShortcutMessages(
 		not_null<PeerData*> peer,
 		BusinessShortcutId id);
-	void sendMessage(MessageToSend &&message);
+	void sendMessage(
+		MessageToSend &&message,
+		std::optional<MsgId> localMessageId = std::nullopt);
 	void sendBotStart(
 		std::shared_ptr<Ui::Show> show,
 		not_null<UserData*> bot,
@@ -428,6 +432,12 @@ public:
 
 	static constexpr auto kJoinErrorDuration = 5 * crl::time(1000);
 
+	static void ProcessRecentSelfForwards(
+		not_null<Main::Session*> session,
+		const MTPUpdates &updates,
+		PeerId targetPeerId,
+		PeerId fromPeerId);
+
 private:
 	struct MessageDataRequest {
 		using Callbacks = std::vector<Fn<void()>>;
