@@ -83,9 +83,12 @@ namespace {
 
 constexpr auto kTooltipDuration = 3 * crl::time(1000);
 constexpr auto kHorizontalBar = QChar(0x2015);
+constexpr auto kSpinnerRows = 6;
+constexpr auto kSpinDuration = crl::time(120);
 
 using Ui::AddTableRow;
 using Ui::TableRowTooltipData;
+using SpinnerState = Data::GiftUpgradeSpinner::State;
 
 [[nodiscard]] QString CreateMessageLink(
 		not_null<Main::Session*> session,
@@ -151,7 +154,7 @@ using Ui::TableRowTooltipData;
 	auto result = object_ptr<Ui::RpWidget>(parent);
 	const auto raw = result.data();
 
-	raw->paintRequest() | rpl::start_with_next([=] {
+	raw->paintRequest() | rpl::on_next([=] {
 		auto p = QPainter(raw);
 		const auto &icon = st::giveawayGiftCodeLinkCopy;
 		const auto left = (raw->width() - icon.width()) / 2;
@@ -232,10 +235,10 @@ using Ui::TableRowTooltipData;
 		tr::lng_gift_value_minimum_price_tooltip(
 			tr::now,
 			lt_amount,
-			Ui::Text::Bold(text.text),
+			tr::bold(text.text),
 			lt_gift,
-			Ui::Text::Bold(unique->title),
-			Ui::Text::WithEntities));
+			tr::bold(unique->title),
+			tr::marked));
 }
 
 [[nodiscard]] object_ptr<Ui::RpWidget> MakeAveragePriceValue(
@@ -251,10 +254,10 @@ using Ui::TableRowTooltipData;
 		tr::lng_gift_value_average_price_tooltip(
 			tr::now,
 			lt_amount,
-			Ui::Text::Bold(text.text),
+			tr::bold(text.text),
 			lt_gift,
-			Ui::Text::Bold(unique->title),
-			Ui::Text::WithEntities));
+			tr::bold(unique->title),
+			tr::marked));
 }
 
 [[nodiscard]] object_ptr<Ui::RpWidget> MakeAttributeValue(
@@ -276,10 +279,179 @@ using Ui::TableRowTooltipData;
 	return MakeValueWithSmallButton(table, label, std::move(text), handler);
 }
 
+[[nodiscard]] object_ptr<Ui::RpWidget> MakeAttributeValue(
+		not_null<Ui::TableLayout*> table,
+		const Data::UniqueGiftAttribute &attribute,
+		Fn<void(not_null<Ui::RpWidget*>, int)> showTooltip,
+		std::shared_ptr<Data::GiftUpgradeSpinner> spinner,
+		std::vector<Data::UniqueGiftAttribute> spinning,
+		SpinnerState finishedState) {
+	if (!spinner) {
+		return MakeAttributeValue(table, attribute, showTooltip);
+	}
+	auto result = object_ptr<Ui::RpWidget>(table);
+	const auto raw = result.get();
+
+	struct Row {
+		Data::UniqueGiftAttribute attribute;
+		object_ptr<Ui::RpWidget> widget;
+		QImage frame;
+	};
+	struct State {
+		int wasIndex = 0;
+		int nowIndex = 0;
+		std::vector<Row> rows;
+		Ui::Animations::Simple animation;
+		QImage fading;
+		Fn<void()> repaint;
+		bool finished = false;
+	};
+	const auto state = raw->lifetime().make_state<State>();
+	state->repaint = [=] { raw->update(); };
+
+	const auto margin = st::giveawayGiftCodeValueMargin;
+	const auto startWithin = [=] {
+		Expects(!state->rows.empty());
+
+		state->wasIndex = state->nowIndex;
+		state->nowIndex = (state->nowIndex + 1) % state->rows.size();
+		state->animation.start(state->repaint, 0., 1., kSpinDuration);
+	};
+	const auto startToTarget = [=] {
+		if (state->nowIndex != 0) {
+			state->wasIndex = state->nowIndex;
+			state->nowIndex = 0;
+			state->animation.start(
+				state->repaint,
+				0.,
+				1.,
+				kSpinDuration * 3,
+				anim::easeOutCubic);
+		}
+	};
+
+	const auto add = [&](const Data::UniqueGiftAttribute &value) {
+		if (state->rows.size() >= kSpinnerRows) {
+			return false;
+		}
+		const auto already = ranges::contains(
+			state->rows,
+			value,
+			&Row::attribute);
+		if (!already) {
+			state->rows.push_back(Row{
+				.attribute = value,
+				.widget = MakeAttributeValue(table, value, showTooltip),
+			});
+			const auto widget = state->rows.back().widget.get();
+			widget->setParent(raw);
+			widget->hide();
+		}
+		return true;
+	};
+	add(attribute);
+	for (const auto &item : spinning) {
+		if (!add(item)) {
+			break;
+		}
+	}
+
+	raw->widthValue() | rpl::on_next([=](int width) {
+		auto height = 0;
+		const auto inner = width - margin.left() - margin.right();
+		if (inner > 0) {
+			for (const auto &row : state->rows) {
+				row.widget->resizeToWidth(inner);
+				row.widget->move(margin.left(), margin.top());
+				height = std::max(height, row.widget->height());
+			}
+		}
+		raw->resize(width, margin.top() + height + margin.bottom());
+		crl::on_main(raw, [=] {
+			for (const auto &row : state->rows) {
+				Ui::SendPendingMoveResizeEvents(row.widget.get());
+			}
+		});
+	}, raw->lifetime());
+
+	style::PaletteChanged() | rpl::on_next([=] {
+		for (auto &row : state->rows) {
+			row.frame = QImage();
+		}
+		state->fading = QImage();
+	}, raw->lifetime());
+
+	raw->paintOn([=](QPainter &p) {
+		if (state->finished) {
+			return;
+		}
+		auto progress = state->animation.value(1.);
+		if (progress >= 1.) {
+			const auto ending = (spinner->state.current() >= finishedState);
+			if (ending) {
+				startToTarget();
+			} else {
+				startWithin();
+			}
+			progress = state->animation.value(1.);
+			if (ending && progress >= 1.) {
+				state->rows.front().widget->show();
+				state->finished = true;
+				return;
+			}
+		}
+		const auto ratio = style::DevicePixelRatio();
+		const auto h = raw->height();
+		if (state->fading.height() != h * ratio) {
+			state->fading = QImage(
+				QSize(1, h) * ratio,
+				QImage::Format_ARGB32_Premultiplied);
+			state->fading.setDevicePixelRatio(ratio);
+			state->fading.fill(Qt::transparent);
+			auto q = QPainter(&state->fading);
+			auto brush = QLinearGradient(0, 0, 0, margin.top());
+			brush.setStops({
+				{ 0., anim::with_alpha(st::boxBg->c, 1.) },
+				{ 1., anim::with_alpha(st::boxBg->c, 0.) },
+			});
+			q.fillRect(0, 0, 1, margin.top(), brush);
+			brush.setStart(0, h);
+			brush.setFinalStop(0, h - margin.bottom());
+			q.fillRect(0, h - margin.bottom(), 1, margin.bottom(), brush);
+		}
+		auto &was = state->rows[state->wasIndex];
+		auto &now = state->rows[state->nowIndex];
+		const auto validate = [&](Row &row) {
+			const auto size = row.widget->size();
+			if (row.frame.size() != size * ratio) {
+				row.frame = Ui::GrabWidgetToImage(row.widget.get());
+			}
+		};
+		validate(was);
+		validate(now);
+		const auto t = progress * (margin.top() + was.widget->height());
+		const auto b = progress * (now.widget->height() + margin.bottom());
+		p.drawImage(
+			margin.left(),
+			margin.top() - int(base::SafeRound(t)),
+			was.frame);
+		p.drawImage(
+			margin.left(),
+			raw->height() - int(base::SafeRound(b)),
+			now.frame);
+		p.drawImage(raw->rect(), state->fading);
+	});
+
+	startWithin();
+
+	return result;
+}
+
 void AddUniqueGiftPropertyRows(
 		not_null<Ui::RpWidget*> container,
 		not_null<Ui::TableLayout*> table,
-		not_null<Data::UniqueGift*> unique) {
+		not_null<Data::UniqueGift*> unique,
+		std::shared_ptr<Data::GiftUpgradeSpinner> spinner) {
 	const auto tooltip = std::make_shared<TableRowTooltipData>(
 		TableRowTooltipData{ .parent = container });
 	const auto showTooltip = [=](
@@ -294,20 +466,57 @@ void AddUniqueGiftPropertyRows(
 		showTooltip(widget, tr::lng_gift_unique_rarity(
 			lt_percent,
 			rpl::single(TextWithEntities{ percent }),
-			Ui::Text::WithEntities));
+			tr::marked));
 	};
+	const auto empty = std::vector<Data::UniqueGiftAttribute>();
+	const auto extract = [&](const auto &list) {
+		auto result = empty;
+		result.reserve(list.size());
+		for (const auto &item : list) {
+			result.push_back(item);
+		}
+		return result;
+	};
+	const auto attributes = spinner ? &spinner->attributes : nullptr;
+	const auto models = spinner ? extract(attributes->models) : empty;
+	const auto patterns = spinner ? extract(attributes->patterns) : empty;
+	const auto backdrops = spinner ? extract(attributes->backdrops) : empty;
+	const auto margin = spinner
+		? style::margins()
+		: st::giveawayGiftCodeValueMargin;
 	AddTableRow(
 		table,
 		tr::lng_gift_unique_model(),
-		MakeAttributeValue(table, unique->model, showRarity));
-	AddTableRow(
-		table,
-		tr::lng_gift_unique_backdrop(),
-		MakeAttributeValue(table, unique->backdrop, showRarity));
+		MakeAttributeValue(
+			table,
+			unique->model,
+			showRarity,
+			spinner,
+			models,
+			SpinnerState::FinishedModel),
+		margin);
 	AddTableRow(
 		table,
 		tr::lng_gift_unique_symbol(),
-		MakeAttributeValue(table, unique->pattern, showRarity));
+		MakeAttributeValue(
+			table,
+			unique->pattern,
+			showRarity,
+			spinner,
+			patterns,
+			SpinnerState::FinishedPattern),
+		margin);
+	AddTableRow(
+		table,
+		tr::lng_gift_unique_backdrop(),
+		MakeAttributeValue(
+			table,
+			unique->backdrop,
+			showRarity,
+			spinner,
+			backdrops,
+			SpinnerState::FinishedBackdrop),
+		margin);
 }
 
 [[nodiscard]] object_ptr<Ui::RpWidget> MakeStarGiftStarsValue(
@@ -371,6 +580,7 @@ void AddUniqueGiftPropertyRows(
 	const auto handler = [=](not_null<Ui::RpWidget*> button) {
 		if (value->initialPriceStars) {
 			show->show(Box(Settings::UniqueGiftValueBox, show, entry, st));
+			return;
 		} else if (*loading) {
 			return;
 		}
@@ -436,15 +646,15 @@ void AddTable(
 		AddTableRow(
 			table,
 			tr::lng_gift_link_label_to(),
-			tr::lng_gift_link_label_to_unclaimed(Ui::Text::WithEntities));
+			tr::lng_gift_link_label_to_unclaimed(tr::marked));
 	}
 	AddTableRow(
 		table,
 		tr::lng_gift_link_label_gift(),
 		tr::lng_gift_link_gift_premium(
 			lt_duration,
-			GiftDurationValue(current.days) | Ui::Text::ToWithEntities(),
-			Ui::Text::WithEntities));
+			GiftDurationValue(current.days) | rpl::map(tr::marked),
+			tr::marked));
 	if (!skipReason && current.from) {
 		const auto reason = AddTableRow(
 			table,
@@ -452,15 +662,14 @@ void AddTable(
 			(current.giveawayId
 				? ((current.to
 					? tr::lng_gift_link_reason_giveaway
-					: tr::lng_gift_link_reason_unclaimed)(
-						) | Ui::Text::ToLink())
+					: tr::lng_gift_link_reason_unclaimed)(tr::link))
 				: current.giveaway
 				? ((current.to
 					? tr::lng_gift_link_reason_giveaway
 					: tr::lng_gift_link_reason_unclaimed)(
-						Ui::Text::WithEntities
-					) | rpl::type_erased())
-				: tr::lng_gift_link_reason_chosen(Ui::Text::WithEntities)));
+						tr::marked
+					) | rpl::type_erased)
+				: tr::lng_gift_link_reason_chosen(tr::marked)));
 		reason->setClickHandlerFilter([=](const auto &...) {
 			if (const auto window = show->resolveWindow()) {
 				window->showPeerHistory(
@@ -475,7 +684,7 @@ void AddTable(
 		AddTableRow(
 			table,
 			tr::lng_gift_link_label_date(),
-			rpl::single(Ui::Text::WithEntities(
+			rpl::single(tr::marked(
 				langDateTime(base::unixtime::parse(current.date)))));
 	}
 }
@@ -516,11 +725,11 @@ void ShowAlreadyPremiumToast(
 		.text = tr::lng_gift_link_already_about(
 			tr::now,
 			lt_date,
-			Ui::Text::Bold(langDateTime(base::unixtime::parse(date))),
+			tr::bold(langDateTime(base::unixtime::parse(date))),
 			lt_link,
-			Ui::Text::Link(
-				Ui::Text::Bold(tr::lng_gift_link_already_link(tr::now))),
-			Ui::Text::WithEntities),
+			tr::link(
+				tr::bold(tr::lng_gift_link_already_link(tr::now))),
+			tr::marked),
 		.filter = crl::guard(navigation, shareLink),
 		.duration = 6 * crl::time(1000),
 	});
@@ -579,8 +788,8 @@ void GiftCodeBox(
 					tr::lng_gift_link_title()),
 				.about = rpl::conditional(
 					state->used.value(),
-					tr::lng_gift_link_used_about(Ui::Text::RichLangValue),
-					tr::lng_gift_link_about(Ui::Text::RichLangValue)),
+					tr::lng_gift_link_used_about(tr::rich),
+					tr::lng_gift_link_about(tr::rich)),
 				.light = true,
 			}));
 
@@ -605,7 +814,7 @@ void GiftCodeBox(
 
 	auto shareLink = tr::lng_gift_link_also_send_link(
 	) | rpl::map([](const QString &text) {
-		return Ui::Text::Link(text);
+		return tr::link(text);
 	});
 	auto richDate = [](const Api::GiftCode &data) {
 		return TextWithEntities{
@@ -620,11 +829,11 @@ void GiftCodeBox(
 				tr::lng_gift_link_used_footer(
 					lt_date,
 					state->data.value() | rpl::map(richDate),
-					Ui::Text::WithEntities),
+					tr::marked),
 				tr::lng_gift_link_also_send(
 					lt_link,
 					std::move(shareLink),
-					Ui::Text::WithEntities)),
+					tr::marked)),
 			st::giveawayGiftCodeFooter),
 		st::giveawayGiftCodeFooterMargin,
 		style::al_top);
@@ -640,7 +849,7 @@ void GiftCodeBox(
 		box->closeBox();
 	});
 	box->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		close->moveToRight(0, 0);
 	}, box->lifetime());
 
@@ -706,8 +915,8 @@ void GiftCodePendingBox(
 					.title = tr::lng_gift_link_title(),
 					.about = tr::lng_gift_link_pending_about(
 						lt_user,
-						rpl::single(Ui::Text::Link(resultToName)),
-						Ui::Text::RichLangValue),
+						rpl::single(tr::link(resultToName)),
+						tr::rich),
 					.light = true,
 				}));
 
@@ -727,7 +936,7 @@ void GiftCodePendingBox(
 			spoiler->update();
 		})->start();
 		linkLabel->sizeValue(
-		) | rpl::start_with_next([=](const QSize &s) {
+		) | rpl::on_next([=](const QSize &s) {
 			spoiler->setGeometry(Rect(s));
 		}, spoiler->lifetime());
 		const auto spoilerCached = Ui::SpoilerMessCached(
@@ -735,7 +944,7 @@ void GiftCodePendingBox(
 			st::giveawayGiftCodeLink.textFg->c);
 		const auto textHeight = st::giveawayGiftCodeLink.style.font->height;
 		spoiler->paintRequest(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			auto p = QPainter(spoiler);
 			const auto rect = spoiler->rect();
 			const auto r = rect
@@ -769,7 +978,7 @@ void GiftCodePendingBox(
 	const auto closeCallback = [=] { box->closeBox(); };
 	close->setClickedCallback(closeCallback);
 	box->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		close->moveToRight(0, 0);
 	}, box->lifetime());
 
@@ -830,20 +1039,20 @@ void GiveawayInfoBox(
 			lt_cup,
 			rpl::single(
 				TextWithEntities{ QString::fromUtf8("\xf0\x9f\x8f\x86") }),
-			Ui::Text::WithEntities)
+			tr::marked)
 		: (info.credits)
 		? tr::lng_prizes_you_won_credits(
 			lt_amount,
 			tr::lng_prizes_you_won_credits_amount(
 				lt_count,
 				rpl::single(float64(info.credits)),
-				Ui::Text::Bold),
+				tr::bold),
 			lt_cup,
 			rpl::single(
 				TextWithEntities{ QString::fromUtf8("\xf0\x9f\x8f\x86") }),
-			Ui::Text::WithEntities)
+			tr::marked)
 		: (info.state == State::Finished)
-		? tr::lng_prizes_you_didnt(Ui::Text::WithEntities)
+		? tr::lng_prizes_you_didnt(tr::marked)
 		: (rpl::producer<TextWithEntities>)(nullptr);
 
 	if (resultText) {
@@ -862,7 +1071,7 @@ void GiveawayInfoBox(
 				std::move(label),
 				QMargins(0, skip, 0, skip)),
 			style::al_justify);
-		result->paintRequest() | rpl::start_with_next([=] {
+		result->paintRequest() | rpl::on_next([=] {
 			auto p = QPainter(result);
 			p.setPen(Qt::NoPen);
 			p.setBrush(st::boxDividerBg);
@@ -895,14 +1104,14 @@ void GiveawayInfoBox(
 					: tr::lng_prizes_credits_admins)(
 						tr::now,
 						lt_channel,
-						Ui::Text::Bold(first),
+						tr::bold(first),
 						lt_amount,
 						tr::lng_prizes_credits_admins_amount(
 							tr::now,
 							lt_count_decimal,
 							float64(credits),
-							Ui::Text::Bold),
-						Ui::Text::RichLangValue)
+							tr::bold),
+						tr::rich)
 				: (group
 					? tr::lng_prizes_admins_group
 					: tr::lng_prizes_admins)(
@@ -910,11 +1119,11 @@ void GiveawayInfoBox(
 						lt_count,
 						quantity,
 						lt_channel,
-						Ui::Text::Bold(first),
+						tr::bold(first),
 						lt_duration,
 						TextWithEntities{ GiftDuration(months * 30) },
-						Ui::Text::RichLangValue),
-			Ui::Text::RichLangValue));
+						tr::rich),
+			tr::rich));
 	const auto many = start
 		? (start->channels.size() > 1)
 		: (results->additionalPeersCount > 0);
@@ -934,8 +1143,8 @@ void GiveawayInfoBox(
 				lt_count,
 				count,
 				lt_channel,
-				Ui::Text::Bold(first),
-				Ui::Text::RichLangValue)
+				tr::bold(first),
+				tr::rich)
 		: (many
 			? tr::lng_prizes_winners_new_of_many
 			: tr::lng_prizes_winners_new_of_one)(
@@ -943,11 +1152,11 @@ void GiveawayInfoBox(
 				lt_count,
 				count,
 				lt_channel,
-				Ui::Text::Bold(first),
+				tr::bold(first),
 				lt_start_date,
-				Ui::Text::Bold(
+				tr::bold(
 					langDateTime(base::unixtime::parse(info.startDate))),
-				Ui::Text::RichLangValue);
+				tr::rich);
 	const auto additionalPrize = results
 		? results->additionalPrize
 		: start->additionalPrize;
@@ -959,10 +1168,10 @@ void GiveawayInfoBox(
 				lt_count,
 				count,
 				lt_channel,
-				Ui::Text::Bold(first),
+				tr::bold(first),
 				lt_prize,
 				TextWithEntities{ additionalPrize },
-				Ui::Text::RichLangValue));
+				tr::rich));
 	}
 	const auto untilDate = start
 		? start->untilDate
@@ -972,17 +1181,17 @@ void GiveawayInfoBox(
 		: tr::lng_prizes_how_when_finish)(
 			tr::now,
 			lt_date,
-			Ui::Text::Bold(langDayOfMonthFull(
+			tr::bold(langDayOfMonthFull(
 				base::unixtime::parse(untilDate).date())),
 			lt_winners,
 			winners,
-			Ui::Text::RichLangValue));
+			tr::rich));
 	if (info.activatedCount > 0) {
 		text.append(' ').append(tr::lng_prizes_end_activated(
 			tr::now,
 			lt_count,
 			info.activatedCount,
-			Ui::Text::RichLangValue));
+			tr::rich));
 	}
 	if (!info.giftCode.isEmpty()
 		|| info.state == State::Finished
@@ -996,8 +1205,8 @@ void GiveawayInfoBox(
 				: tr::lng_prizes_how_no_admin)(
 					tr::now,
 					lt_channel,
-					Ui::Text::Bold(channel->name()),
-					Ui::Text::RichLangValue));
+					tr::bold(channel->name()),
+					tr::rich));
 		} else if (info.tooEarlyDate) {
 			const auto channel = controller->session().data().channel(
 				info.adminChannelId);
@@ -1006,33 +1215,33 @@ void GiveawayInfoBox(
 				: tr::lng_prizes_how_no_joined)(
 					tr::now,
 					lt_date,
-					Ui::Text::Bold(
+					tr::bold(
 						langDateTime(
 							base::unixtime::parse(info.tooEarlyDate))),
-					Ui::Text::RichLangValue));
+					tr::rich));
 		} else if (!info.disallowedCountry.isEmpty()) {
 			text.append("\n\n").append(tr::lng_prizes_how_no_country(
 				tr::now,
-				Ui::Text::RichLangValue));
+				tr::rich));
 		} else if (info.participating) {
 			text.append("\n\n").append((many
 				? tr::lng_prizes_how_yes_joined_many
 				: tr::lng_prizes_how_yes_joined_one)(
 					tr::now,
 					lt_channel,
-					Ui::Text::Bold(first),
-					Ui::Text::RichLangValue));
+					tr::bold(first),
+					tr::rich));
 		} else {
 			text.append("\n\n").append((many
 				? tr::lng_prizes_how_participate_many
 				: tr::lng_prizes_how_participate_one)(
 					tr::now,
 					lt_channel,
-					Ui::Text::Bold(first),
+					tr::bold(first),
 					lt_date,
-					Ui::Text::Bold(langDayOfMonthFull(
+					tr::bold(langDayOfMonthFull(
 						base::unixtime::parse(untilDate).date())),
-					Ui::Text::RichLangValue));
+					tr::rich));
 		}
 	}
 	const auto padding = st::boxPadding;
@@ -1059,7 +1268,7 @@ void GiveawayInfoBox(
 		const auto bg = wrap->lifetime().make_state<Ui::RoundRect>(
 			st::boxRadius,
 			st::attentionBoxButton.textBgOver);
-		wrap->paintRequest() | rpl::start_with_next([=] {
+		wrap->paintRequest() | rpl::on_next([=] {
 			auto p = QPainter(wrap);
 			bg->paint(p, wrap->rect());
 		}, wrap->lifetime());
@@ -1141,7 +1350,7 @@ struct AddedUniqueDetails {
 	const auto icon = Ui::CreateChild<Ui::IconButton>(
 		raw,
 		st::giveawayGiftMessageRemove);
-	raw->widthValue() | rpl::start_with_next([=](int outer) {
+	raw->widthValue() | rpl::on_next([=](int outer) {
 		label->resizeToWidth(outer - icon->width());
 		const auto height = std::max(label->height(), icon->height());
 
@@ -1170,7 +1379,7 @@ struct AddedUniqueDetails {
 					rpl::single(
 						Ui::Text::IconEmoji(&st::starIconEmoji).append(
 							Lang::FormatCountDecimal(removeCost))),
-					Ui::Text::RichLangValue),
+					tr::rich),
 				.title = tr::lng_gift_unique_info_remove_title(),
 			});
 			box->addRow(
@@ -1203,8 +1412,9 @@ void AddStarGiftTable(
 		not_null<Ui::VerticalLayout*> container,
 		Settings::CreditsEntryBoxStyleOverrides st,
 		const Data::CreditsHistoryEntry &entry,
+		std::shared_ptr<Data::GiftUpgradeSpinner> spinner,
 		Fn<void()> convertToStars,
-		Fn<void()> startUpgrade,
+		bool canStartUpgrade,
 		Fn<void(Fn<void()> removed)> removeDetails) {
 	const auto table = container->add(
 		object_ptr<Ui::TableLayout>(
@@ -1249,8 +1459,8 @@ void AddStarGiftTable(
 			const auto show = [&](const auto &phrase) {
 				showTooltip(badge, phrase(
 					lt_name,
-					rpl::single(Ui::Text::Bold(UniqueGiftName(*unique))),
-					Ui::Text::WithEntities));
+					rpl::single(tr::bold(UniqueGiftName(*unique))),
+					tr::marked));
 			};
 			if (!*was || *was == id) {
 				*was = id;
@@ -1299,8 +1509,8 @@ void AddStarGiftTable(
 				const auto show = [&](const auto &phrase) {
 					showTooltip(badge, phrase(
 						lt_name,
-						rpl::single(Ui::Text::Bold(UniqueGiftName(*unique))),
-						Ui::Text::WithEntities));
+						rpl::single(tr::bold(UniqueGiftName(*unique))),
+						tr::marked));
 				};
 				if (!*was || *was == id) {
 					*was = id;
@@ -1371,24 +1581,24 @@ void AddStarGiftTable(
 		AddTableRow(
 			table,
 			tr::lng_gift_link_label_first_sale(),
-			rpl::single(Ui::Text::WithEntities(
+			rpl::single(tr::marked(
 				langDateTime(entry.firstSaleDate))));
 	}
 	if (!unique && !entry.lastSaleDate.isNull()) {
 		AddTableRow(
 			table,
 			tr::lng_gift_link_label_last_sale(),
-			rpl::single(Ui::Text::WithEntities(
+			rpl::single(tr::marked(
 				langDateTime(entry.lastSaleDate))));
 	}
 	if (!unique && !entry.date.isNull()) {
 		AddTableRow(
 			table,
 			tr::lng_gift_link_label_date(),
-			rpl::single(Ui::Text::WithEntities(langDateTime(entry.date))));
+			rpl::single(tr::marked(langDateTime(entry.date))));
 	}
 	if (unique) {
-		AddUniqueGiftPropertyRows(container, table, unique);
+		AddUniqueGiftPropertyRows(container, table, unique, spinner);
 	} else {
 		AddTableRow(
 			table,
@@ -1415,7 +1625,7 @@ void AddStarGiftTable(
 				? tr::lng_gift_availability_none(
 					lt_amount,
 					std::move(amount),
-					Ui::Text::WithEntities)
+					tr::marked)
 				: (unique
 					? tr::lng_gift_unique_availability
 					: tr::lng_gift_availability_left)(
@@ -1423,13 +1633,13 @@ void AddStarGiftTable(
 						rpl::single(count * 1.),
 						lt_amount,
 						std::move(amount),
-						Ui::Text::WithEntities)));
+						tr::marked)));
 	}
-	if (!unique && !entry.soldOutInfo && startUpgrade) {
+	if (!unique && !entry.soldOutInfo && canStartUpgrade) {
 		AddTableRow(
 			table,
 			tr::lng_gift_unique_status(),
-			tr::lng_gift_unique_status_non(Ui::Text::WithEntities));
+			tr::lng_gift_unique_status_non(tr::marked));
 	}
 	if (unique) {
 		if (unique->value) {
@@ -1451,37 +1661,37 @@ void AddStarGiftTable(
 				? (original.message.empty()
 					? tr::lng_gift_unique_info_sender(
 						lt_from,
-						rpl::single(Ui::Text::Link(from->name(), 2)),
+						rpl::single(tr::link(from->name(), 2)),
 						lt_recipient,
-						rpl::single(Ui::Text::Link(to->name(), 1)),
+						rpl::single(tr::link(to->name(), 1)),
 						lt_date,
 						rpl::single(dateText),
-						Ui::Text::WithEntities)
+						tr::marked)
 					: tr::lng_gift_unique_info_sender_comment(
 						lt_from,
-						rpl::single(Ui::Text::Link(from->name(), 2)),
+						rpl::single(tr::link(from->name(), 2)),
 						lt_recipient,
-						rpl::single(Ui::Text::Link(to->name(), 1)),
+						rpl::single(tr::link(to->name(), 1)),
 						lt_date,
 						rpl::single(dateText),
 						lt_text,
 						rpl::single(original.message),
-						Ui::Text::WithEntities))
+						tr::marked))
 				: (original.message.empty()
 					? tr::lng_gift_unique_info_reciever(
 						lt_recipient,
-						rpl::single(Ui::Text::Link(to->name(), 1)),
+						rpl::single(tr::link(to->name(), 1)),
 						lt_date,
 						rpl::single(dateText),
-						Ui::Text::WithEntities)
+						tr::marked)
 					: tr::lng_gift_unique_info_reciever_comment(
 						lt_recipient,
-						rpl::single(Ui::Text::Link(to->name(), 1)),
+						rpl::single(tr::link(to->name(), 1)),
 						lt_date,
 						rpl::single(dateText),
 						lt_text,
 						rpl::single(original.message),
-						Ui::Text::WithEntities));
+						tr::marked));
 			const auto tmp = std::make_shared<Ui::RpWidget*>(nullptr);
 			auto made = MakeUniqueDetails(
 				show,
@@ -1535,7 +1745,7 @@ void AddTransferGiftTable(
 			container,
 			st::giveawayGiftCodeTable),
 		st::giveawayGiftCodeTableMargin);
-	AddUniqueGiftPropertyRows(container, table, unique.get());
+	AddUniqueGiftPropertyRows(container, table, unique.get(), nullptr);
 	if (const auto value = unique->value.get()) {
 		AddTableRow(
 			table,
@@ -1584,7 +1794,7 @@ void AddCreditsHistoryEntryTable(
 				table,
 				tr::lng_gift_link_label_reason(),
 				tr::lng_credits_box_history_entry_reason_star_ref(
-					Ui::Text::WithEntities));
+					tr::marked));
 		}
 	}
 	if (starrefRecipientId && entry.starrefAmount && !entry.giftResale) {
@@ -1650,7 +1860,7 @@ void AddCreditsHistoryEntryTable(
 				entry.bareMsgId);
 			auto label = object_ptr<Ui::FlatLabel>(
 				table,
-				rpl::single(Ui::Text::Link(link)),
+				rpl::single(tr::link(link)),
 				table->st().defaultValue);
 			label->setClickHandlerFilter([=](const auto &...) {
 				if (const auto window = show->resolveWindow()) {
@@ -1672,13 +1882,13 @@ void AddCreditsHistoryEntryTable(
 			table,
 			tr::lng_credits_box_history_entry_via(),
 			tr::lng_credits_box_history_entry_app_store(
-				Ui::Text::RichLangValue));
+				tr::rich));
 	} else if (entry.peerType == Type::PlayMarket) {
 		AddTableRow(
 			table,
 			tr::lng_credits_box_history_entry_via(),
 			tr::lng_credits_box_history_entry_play_market(
-				Ui::Text::RichLangValue));
+				tr::rich));
 	} else if (entry.peerType == Type::Fragment) {
 		AddTableRow(
 			table,
@@ -1688,18 +1898,18 @@ void AddCreditsHistoryEntryTable(
 			((entry.gift && entry.credits.stars())
 				? tr::lng_credits_box_history_entry_anonymous
 				: tr::lng_credits_box_history_entry_fragment)(
-					Ui::Text::RichLangValue));
+					tr::rich));
 	} else if (entry.peerType == Type::Ads) {
 		AddTableRow(
 			table,
 			tr::lng_credits_box_history_entry_via(),
-			tr::lng_credits_box_history_entry_ads(Ui::Text::RichLangValue));
+			tr::lng_credits_box_history_entry_ads(tr::rich));
 	} else if (entry.peerType == Type::PremiumBot) {
 		AddTableRow(
 			table,
 			tr::lng_credits_box_history_entry_via(),
 			tr::lng_credits_box_history_entry_via_premium_bot(
-				Ui::Text::RichLangValue));
+				tr::rich));
 	}
 	if (entry.bareGiveawayMsgId) {
 		AddTableRow(
@@ -1715,7 +1925,7 @@ void AddCreditsHistoryEntryTable(
 			tr::lng_gift_stars_title(
 				lt_count,
 				rpl::single(entry.credits.value()),
-				Ui::Text::RichLangValue));
+				tr::rich));
 	}
 	{
 		const auto link = CreateMessageLink(
@@ -1728,7 +1938,7 @@ void AddCreditsHistoryEntryTable(
 				tr::lng_gift_link_label_reason(),
 				tr::lng_gift_link_reason_giveaway(
 				) | rpl::map([link](const QString &text) {
-					return Ui::Text::Link(text, link);
+					return tr::link(text, link);
 				}));
 		}
 	}
@@ -1737,7 +1947,7 @@ void AddCreditsHistoryEntryTable(
 			table,
 			tr::lng_gift_link_label_reason(),
 			tr::lng_credits_box_history_entry_subscription(
-				Ui::Text::WithEntities));
+				tr::marked));
 	}
 	if (entry.paidMessagesAmount) {
 		auto value = Ui::Text::IconEmoji(&st::starIconEmojiColored);
@@ -1756,7 +1966,7 @@ void AddCreditsHistoryEntryTable(
 			tr::lng_months(
 				lt_count,
 				rpl::single(1. * months),
-				Ui::Text::WithEntities));
+				tr::marked));
 	}
 	if (!entry.id.isEmpty()) {
 		auto label = MakeMaybeMultilineTokenValue(table, entry.id, st);
@@ -1777,27 +1987,27 @@ void AddCreditsHistoryEntryTable(
 			table,
 			tr::lng_credits_box_history_entry_floodskip_row(),
 			rpl::single(
-				Ui::Text::WithEntities(
+				tr::marked(
 					Lang::FormatCountDecimal(entry.floodSkip))));
 	}
 	if (!entry.date.isNull()) {
 		AddTableRow(
 			table,
 			tr::lng_gift_link_label_date(),
-			rpl::single(Ui::Text::WithEntities(langDateTime(entry.date))));
+			rpl::single(tr::marked(langDateTime(entry.date))));
 	}
 	if (!entry.successDate.isNull()) {
 		AddTableRow(
 			table,
 			tr::lng_credits_box_history_entry_success_date(),
-			rpl::single(Ui::Text::WithEntities(langDateTime(entry.date))));
+			rpl::single(tr::marked(langDateTime(entry.date))));
 	}
 	if (!entry.successLink.isEmpty()) {
 		AddTableRow(
 			table,
 			tr::lng_credits_box_history_entry_success_url(),
 			rpl::single(
-				Ui::Text::Link(entry.successLink, entry.successLink)));
+				tr::link(entry.successLink, entry.successLink)));
 	}
 	if (entry.limitedCount > 0 && entry.limitedLeft >= 0) {
 		AddTableRow(
@@ -1810,7 +2020,7 @@ void AddCreditsHistoryEntryTable(
 				rpl::single(TextWithEntities{
 					Lang::FormatCountDecimal(entry.limitedCount)
 				}),
-				Ui::Text::WithEntities));
+				tr::marked));
 	}
 }
 
@@ -1844,7 +2054,7 @@ void AddSubscriptionEntryTable(
 		AddTableRow(
 			table,
 			tr::lng_credits_subscription_row_to(),
-			rpl::single(Ui::Text::WithEntities(s.title)));
+			rpl::single(tr::marked(s.title)));
 	}
 	if (!s.until.isNull()) {
 		if (s.subscription.period > 0) {
@@ -1854,7 +2064,7 @@ void AddSubscriptionEntryTable(
 					table,
 					tr::lng_group_invite_joined_row_date(),
 					rpl::single(
-						Ui::Text::WithEntities(langDateTime(subscribed))));
+						tr::marked(langDateTime(subscribed))));
 			}
 		}
 		AddTableRow(
@@ -1864,7 +2074,7 @@ void AddSubscriptionEntryTable(
 				: s.cancelled
 				? tr::lng_credits_subscription_row_next_off()
 				: tr::lng_credits_subscription_row_next_on(),
-			rpl::single(Ui::Text::WithEntities(langDateTime(s.until))));
+			rpl::single(tr::marked(langDateTime(s.until))));
 	}
 }
 
@@ -1888,7 +2098,7 @@ void AddSubscriberEntryTable(
 		AddTableRow(
 			table,
 			tr::lng_group_invite_joined_row_date(),
-			rpl::single(Ui::Text::WithEntities(langDateTime(d))));
+			rpl::single(tr::marked(langDateTime(d))));
 	}
 }
 
@@ -1919,7 +2129,7 @@ void AddCreditsBoostTable(
 			tr::lng_gift_stars_title(
 				lt_count,
 				rpl::single(float64(b.credits)),
-				Ui::Text::RichLangValue));
+				tr::rich));
 	}
 	{
 		const auto link = CreateMessageLink(
@@ -1932,7 +2142,7 @@ void AddCreditsBoostTable(
 				tr::lng_gift_link_label_reason(),
 				tr::lng_gift_link_reason_giveaway(
 				) | rpl::map([link](const QString &text) {
-					return Ui::Text::Link(text, link);
+					return tr::link(text, link);
 				}));
 		}
 	}
@@ -1940,13 +2150,13 @@ void AddCreditsBoostTable(
 		AddTableRow(
 			table,
 			tr::lng_gift_link_label_date(),
-			rpl::single(Ui::Text::WithEntities(langDateTime(b.date))));
+			rpl::single(tr::marked(langDateTime(b.date))));
 	}
 	if (!b.expiresAt.isNull()) {
 		AddTableRow(
 			table,
 			tr::lng_gift_until(),
-			rpl::single(Ui::Text::WithEntities(langDateTime(b.expiresAt))));
+			rpl::single(tr::marked(langDateTime(b.expiresAt))));
 	}
 }
 
@@ -2008,7 +2218,7 @@ void AddUniqueGiftValueTable(
 				value->initialSalePrice,
 				value->currency,
 				true)),
-			Ui::Text::WithEntities),
+			tr::marked),
 		helper.context());
 	if (value->lastSaleDate) {
 		AddTableRow(
