@@ -29,7 +29,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/boxes/confirm_box.h"
 #include "ui/boxes/show_or_premium_box.h"
 #include "ui/effects/premium_graphics.h"
-#include "ui/text/text_utilities.h" // Ui::Text::RichLangValue
+#include "ui/text/text_utilities.h" // tr::rich
 #include "ui/toast/toast.h"
 #include "ui/widgets/buttons.h"
 #include "ui/widgets/checkbox.h"
@@ -191,17 +191,17 @@ void FillUpgradeToPremiumCover(
 	for (auto i = 0; i != names; ++i) {
 		const auto name = userpicUsers[i]->shortName();
 		if (text.empty()) {
-			text = Ui::Text::Bold(name);
+			text = tr::bold(name);
 		} else if (i == names - 1 && !remaining) {
 			text = tr::lng_invite_upgrade_users_few(
 				tr::now,
 				lt_users,
 				text,
 				lt_last,
-				Ui::Text::Bold(name),
-				Ui::Text::RichLangValue);
+				tr::bold(name),
+				tr::rich);
 		} else {
-			text.append(", ").append(Ui::Text::Bold(name));
+			text.append(", ").append(tr::bold(name));
 		}
 	}
 	if (remaining > 0) {
@@ -211,7 +211,7 @@ void FillUpgradeToPremiumCover(
 			remaining,
 			lt_users,
 			text,
-			Ui::Text::RichLangValue);
+			tr::rich);
 	}
 	const auto inviteOnly = !forbidden.premiumAllowsInvite.empty()
 		&& (forbidden.premiumAllowsWrite.size() != forbidden.users.size());
@@ -227,7 +227,7 @@ void FillUpgradeToPremiumCover(
 				int(userpicUsers.size()),
 				lt_users,
 				text,
-				Ui::Text::RichLangValue);
+				tr::rich);
 	container->add(
 		object_ptr<Ui::FlatLabel>(
 			container,
@@ -273,7 +273,7 @@ void SimpleForbiddenBox(
 
 	Data::AmPremiumValue(
 		&peer->session()
-	) | rpl::skip(1) | rpl::start_with_next([=] {
+	) | rpl::skip(1) | rpl::on_next([=] {
 		box->closeBox();
 	}, box->lifetime());
 }
@@ -474,11 +474,11 @@ void InviteForbiddenController::setSimpleCover() {
 		? phraseCounted(
 			lt_count,
 			rpl::single<float64>(count),
-			Ui::Text::RichLangValue)
+			tr::rich)
 		: phraseNamed(
 			lt_user,
 			rpl::single(TextWithEntities{ _users.front()->name() }),
-			Ui::Text::RichLangValue);
+			tr::rich);
 	delegate()->peerListSetAboveWidget(object_ptr<Ui::PaddingWrap<>>(
 		(QWidget*)nullptr,
 		object_ptr<Ui::FlatLabel>(
@@ -530,18 +530,18 @@ void InviteForbiddenController::setComplexCover() {
 				? tr::lng_invite_upgrade_via_channel_about
 				: tr::lng_invite_upgrade_via_group_about)(
 					tr::now,
-					Ui::Text::WithEntities)
+					tr::marked)
 			: (_forbidden.users.size() == 1
 				? tr::lng_via_link_cant_one(
 					tr::now,
 					lt_user,
 					TextWithEntities{ _forbidden.users.front()->shortName() },
-					Ui::Text::RichLangValue)
+					tr::rich)
 				: tr::lng_via_link_cant_many(
 					tr::now,
 					lt_count,
 					int(_forbidden.users.size()),
-					Ui::Text::RichLangValue));
+					tr::rich));
 		container->add(
 			object_ptr<Ui::FlatLabel>(
 				container,
@@ -555,7 +555,7 @@ void InviteForbiddenController::setComplexCover() {
 
 void InviteForbiddenController::prepare() {
 	session().api().premium().someMessageMoneyRestrictionsResolved(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto stars = 0;
 		const auto process = [&](not_null<PeerListRow*> raw) {
 			const auto row = static_cast<ForbiddenRow*>(raw.get());
@@ -667,7 +667,7 @@ void InviteForbiddenController::send(
 	if (!waiting.empty()) {
 		session().changes().peerUpdates(
 			Data::PeerUpdate::Flag::FullInfo
-		) | rpl::start_with_next([=](const Data::PeerUpdate &update) {
+		) | rpl::on_next([=](const Data::PeerUpdate &update) {
 			if (waiting.contains(update.peer)) {
 				withPaymentApproved(alreadyApproved);
 			}
@@ -677,7 +677,7 @@ void InviteForbiddenController::send(
 			session().credits().loadedValue(
 			) | rpl::filter(
 				rpl::mappers::_1
-			) | rpl::take(1) | rpl::start_with_next([=] {
+			) | rpl::take(1) | rpl::on_next([=] {
 				withPaymentApproved(alreadyApproved);
 			}, _paymentCheckLifetime);
 		}
@@ -721,12 +721,12 @@ void InviteForbiddenController::send(
 				tr::now,
 				lt_user,
 				TextWithEntities{ list.front()->name() },
-				Ui::Text::RichLangValue)
+				tr::rich)
 			: tr::lng_via_link_shared_many(
 				tr::now,
 				lt_count,
 				int(list.size()),
-				Ui::Text::RichLangValue);
+				tr::rich);
 		close();
 		show->showToast(std::move(text));
 		return true;
@@ -750,7 +750,7 @@ void InviteForbiddenController::send(
 		_peer->session().changes().peerUpdates(
 			_peer,
 			Data::PeerUpdate::Flag::FullInfo
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			sendForFull();
 		}, lifetime());
 	}
@@ -926,7 +926,7 @@ void AddParticipantsBoxController::addInviteLinkButton() {
 		st::inviteViaLinkIcon,
 		QPoint());
 	button->entity()->heightValue(
-	) | rpl::start_with_next([=](int height) {
+	) | rpl::on_next([=](int height) {
 		icon->moveToLeft(
 			st::inviteViaLinkIconPosition.x(),
 			(height - st::inviteViaLinkIcon.height()) / 2);
@@ -938,7 +938,7 @@ void AddParticipantsBoxController::addInviteLinkButton() {
 	button->entity()->events(
 	) | rpl::filter([=](not_null<QEvent*> e) {
 		return (e->type() == QEvent::Enter);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		delegate()->peerListMouseLeftGeometry();
 	}, button->lifetime());
 	delegate()->peerListSetAboveWidget(std::move(button));
@@ -989,14 +989,14 @@ void AddParticipantsBoxController::inviteSelectedUsers(
 				{ users.front()->name()},
 				lt_group,
 				{ _peer->name()},
-				Ui::Text::RichLangValue)
+				tr::rich)
 			: tr::lng_participant_invite_sure_many(
 				tr::now,
 				lt_count,
 				int(users.size()),
 				lt_group,
 				{ _peer->name() },
-				Ui::Text::RichLangValue);
+				tr::rich);
 		Ui::ConfirmBox(box, {
 			.text = std::move(text),
 			.confirmed = crl::guard(weak, [=](Fn<void()> &&close) {
@@ -1062,7 +1062,7 @@ void AddParticipantsBoxController::Start(
 			[=] { box->closeBox(); });
 		if (justCreated) {
 			const auto weak = base::make_weak(parent);
-			box->boxClosing() | rpl::start_with_next([=] {
+			box->boxClosing() | rpl::on_next([=] {
 				auto params = Window::SectionShow();
 				params.activation = anim::activation::background;
 				if (const auto strong = weak.get()) {
@@ -1145,7 +1145,7 @@ bool ChatInviteForbidden(
 		) | rpl::map(
 			rpl::mappers::_1 > 0
 		) | rpl::distinct_until_changed(
-		) | rpl::start_with_next([=](bool has) {
+		) | rpl::on_next([=](bool has) {
 			box->clearButtons();
 			if (has) {
 				const auto send = box->addButton(tr::lng_via_link_send(), [=] {
@@ -1165,7 +1165,7 @@ bool ChatInviteForbidden(
 
 		Data::AmPremiumValue(
 			&peer->session()
-		) | rpl::skip(1) | rpl::start_with_next([=] {
+		) | rpl::skip(1) | rpl::on_next([=] {
 			box->closeBox();
 		}, box->lifetime());
 	};
@@ -1272,7 +1272,7 @@ void AddSpecialBoxController::prepareChatRows(not_null<ChatData*> chat) {
 	chat->session().changes().peerUpdates(
 		chat,
 		UpdateFlag::Members | UpdateFlag::Admins
-	) | rpl::start_with_next([=](const Data::PeerUpdate &update) {
+	) | rpl::on_next([=](const Data::PeerUpdate &update) {
 		_additional.fillFromPeer();
 		if (update.flags & UpdateFlag::Members) {
 			rebuildChatRows(chat);
