@@ -377,7 +377,7 @@ void SettingsBox(
 		))->toggleOn(rpl::single(
 			settings.groupCallNoiseSuppression()
 		))->toggledChanges(
-		) | rpl::start_with_next([=](bool enabled) {
+		) | rpl::on_next([=](bool enabled) {
 			Core::App().settings().setGroupCallNoiseSuppression(enabled);
 			call->setNoiseSuppression(enabled);
 			Core::App().saveSettingsDelayed();
@@ -457,8 +457,8 @@ void SettingsBox(
 									? tr::lng_group_call_mac_input()
 									: tr::lng_group_call_mac_accessibility())
 							) | rpl::map([](QString a, QString b) {
-								auto result = Ui::Text::RichLangValue(a);
-								result.append("\n\n").append(Ui::Text::RichLangValue(b));
+								auto result = tr::rich(a);
+								result.append("\n\n").append(tr::rich(b));
 								return result;
 							}),
 							st::groupCallBoxLabel),
@@ -482,7 +482,7 @@ void SettingsBox(
 							kCheckAccessibilityInterval
 						) | rpl::filter([] {
 							return base::GlobalShortcutsAllowed();
-						}) | rpl::start_with_next([=] {
+						}) | rpl::on_next([=] {
 							box->closeBox();
 						}, box->lifetime());
 					}
@@ -579,7 +579,7 @@ void SettingsBox(
 				settings.groupCallPushToTalk(),
 				anim::type::instant);
 			pushToTalk->toggledChanges(
-			) | rpl::start_with_next([=](bool toggled) {
+			) | rpl::on_next([=](bool toggled) {
 				if (!toggled) {
 					stopRecording();
 				} else if (!ensureManager()) {
@@ -801,12 +801,12 @@ void SettingsBox(
 		});
 
 		volumeItem->toggleMuteLocallyRequests(
-		) | rpl::start_with_next([=](bool muted) {
+		) | rpl::on_next([=](bool muted) {
 			toggleMute(muted, true);
 		}, volumeItem->lifetime());
 
 		volumeItem->changeVolumeLocallyRequests(
-		) | rpl::start_with_next([=](int volume) {
+		) | rpl::on_next([=](int volume) {
 			changeVolume(volume, true);
 		}, volumeItem->lifetime());
 	}
@@ -849,7 +849,7 @@ void SettingsBox(
 
 	box->setTitle(tr::lng_group_call_settings_title());
 	box->boxClosing(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (canChangeJoinMuted
 			&& muteJoined
 			&& muteJoined->toggled() != joinMuted) {
