@@ -25,7 +25,7 @@ GiftAuctions::GiftAuctions(not_null<Main::Session*> session)
 			_session->data().chatsListLoadedEvents()
 		) | rpl::filter(
 			!rpl::mappers::_1
-		) | rpl::take(1) | rpl::start_with_next([=] {
+		) | rpl::take(1) | rpl::on_next([=] {
 			requestActive();
 		}, _lifetime);
 	});
@@ -43,7 +43,7 @@ rpl::producer<GiftAuctionState> GiftAuctions::state(const QString &slug) {
 		}
 		const auto raw = entry.get();
 
-		raw->changes.events() | rpl::start_with_next([=] {
+		raw->changes.events() | rpl::on_next([=] {
 			consumer.put_next_copy(raw->state);
 		}, lifetime);
 
@@ -112,6 +112,7 @@ void GiftAuctions::requestAcquired(
 				.date = data.vdate().v,
 				.bidAmount = int64(data.vbid_amount().v),
 				.round = data.vround().v,
+				.number = data.vgift_num().value_or_empty(),
 				.position = data.vpos().v,
 				.nameHidden = data.is_name_hidden(),
 			});
@@ -129,6 +130,49 @@ void GiftAuctions::requestAcquired(
 	}).send();
 }
 
+std::optional<Data::UniqueGiftAttributes> GiftAuctions::attributes(
+		uint64 giftId) const {
+	const auto i = _attributes.find(giftId);
+	return (i != end(_attributes) && i->second.waiters.empty())
+		? i->second.lists
+		: std::optional<Data::UniqueGiftAttributes>();
+}
+
+void GiftAuctions::requestAttributes(uint64 giftId, Fn<void()> ready) {
+	auto &entry = _attributes[giftId];
+	entry.waiters.push_back(std::move(ready));
+	if (entry.waiters.size() > 1) {
+		return;
+	}
+	_session->api().request(MTPpayments_GetStarGiftUpgradeAttributes(
+		MTP_long(giftId)
+	)).done([=](const MTPpayments_StarGiftUpgradeAttributes &result) {
+		const auto &attributes = result.data().vattributes().v;
+		auto &entry = _attributes[giftId];
+		auto &info = entry.lists;
+		info.models.reserve(attributes.size());
+		info.patterns.reserve(attributes.size());
+		info.backdrops.reserve(attributes.size());
+		for (const auto &attribute : attributes) {
+			attribute.match([&](const MTPDstarGiftAttributeModel &data) {
+				info.models.push_back(Api::FromTL(_session, data));
+			}, [&](const MTPDstarGiftAttributePattern &data) {
+				info.patterns.push_back(Api::FromTL(_session, data));
+			}, [&](const MTPDstarGiftAttributeBackdrop &data) {
+				info.backdrops.push_back(Api::FromTL(data));
+			}, [](const MTPDstarGiftAttributeOriginalDetails &data) {
+			});
+		}
+		for (const auto &ready : base::take(entry.waiters)) {
+			ready();
+		}
+	}).fail([=] {
+		for (const auto &ready : base::take(_attributes[giftId].waiters)) {
+			ready();
+		}
+	}).send();
+}
+
 rpl::producer<ActiveAuctions> GiftAuctions::active() const {
 	return _activeChanged.events_starting_with_copy(
 		rpl::empty
@@ -233,6 +277,7 @@ void GiftAuctions::requestActive() {
 		result.match([=](const MTPDpayments_starGiftActiveAuctions &data) {
 			const auto owner = &_session->data();
 			owner->processUsers(data.vusers());
+			owner->processChats(data.vchats());
 
 			auto giftsFound = base::flat_set<QString>();
 			const auto &list = data.vauctions().v;
@@ -294,6 +339,7 @@ void GiftAuctions::request(const QString &slug) {
 		const auto &data = result.data();
 
 		_session->data().processUsers(data.vusers());
+		_session->data().processChats(data.vchats());
 
 		raw->state.gift = Api::FromTL(_session, data.vgift());
 		if (!raw->state.gift) {
@@ -367,6 +413,24 @@ void GiftAuctions::apply(
 		entry->giftsLeft = data.vgifts_left().v;
 		entry->currentRound = data.vcurrent_round().v;
 		entry->totalRounds = data.vtotal_rounds().v;
+		const auto &rounds = data.vrounds().v;
+		entry->roundParameters.clear();
+		entry->roundParameters.reserve(rounds.size());
+		for (const auto &round : rounds) {
+			round.match([&](const MTPDstarGiftAuctionRound &data) {
+				entry->roundParameters.push_back({
+					.number = data.vnum().v,
+					.duration = data.vduration().v,
+				});
+			}, [&](const MTPDstarGiftAuctionRoundExtendable &data) {
+				entry->roundParameters.push_back({
+					.number = data.vnum().v,
+					.duration = data.vduration().v,
+					.extendTop = data.vextend_top().v,
+					.extendDuration = data.vextend_window().v,
+				});
+			});
+		}
 		entry->averagePrice = 0;
 	}, [&](const MTPDstarGiftAuctionStateFinished &data) {
 		entry->averagePrice = data.vaverage_price().v;
