@@ -78,6 +78,7 @@ struct CreditsHistoryEntry final {
 	uint64 giftChannelSavedId = 0;
 	uint64 stargiftId = 0;
 	QString giftPrepayUpgradeHash;
+	QString giftTitle;
 	std::shared_ptr<UniqueGift> uniqueGift;
 	Fn<std::vector<CreditsHistoryEntry>()> pinnedSavedGifts;
 	uint64 nextToUpgradeStickerId = 0;
@@ -105,6 +106,7 @@ struct CreditsHistoryEntry final {
 	int starsForDetailsRemove = 0;
 	int premiumMonthsForStars = 0;
 	int floodSkip = 0;
+	int giftNumber = 0;
 	bool converted : 1 = false;
 	bool anonymous : 1 = false;
 	bool stargift : 1 = false;
