@@ -11,7 +11,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "api/api_global_privacy.h"
 #include "api/api_sensitive_content.h"
 #include "api/api_statistics.h"
+#include "api/api_text_entities.h"
 #include "base/timer_rpl.h"
+#include "core/application.h"
 #include "storage/localstorage.h"
 #include "storage/storage_account.h"
 #include "storage/storage_user_photos.h"
@@ -20,6 +22,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/business/data_business_info.h"
 #include "data/components/credits.h"
 #include "data/data_cloud_themes.h"
+#include "data/data_forum.h"
+#include "data/data_forum_icons.h"
 #include "data/data_saved_music.h"
 #include "data/data_session.h"
 #include "data/data_changes.h"
@@ -32,6 +36,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "api/api_peer_photo.h"
 #include "apiwrap.h"
 #include "lang/lang_keys.h"
+#include "window/notifications_manager.h"
 #include "styles/style_chat.h"
 
 namespace {
@@ -84,6 +89,28 @@ bool ApplyBotVerifierSettings(
 
 BotInfo::BotInfo() = default;
 
+BotInfo::~BotInfo() = default;
+
+void BotInfo::ensureForum(not_null<UserData*> that) {
+	if (!_forum) {
+		const auto history = that->owner().history(that);
+		_forum = std::make_unique<Data::Forum>(history);
+		history->forumChanged(nullptr);
+	}
+}
+
+Data::Forum *BotInfo::forum() const {
+	return _forum.get();
+}
+
+std::unique_ptr<Data::Forum> BotInfo::takeForumData() {
+	if (auto result = base::take(_forum)) {
+		result->history()->forumChanged(result.get());
+		return result;
+	}
+	return nullptr;
+}
+
 Data::LastseenStatus LastseenFromMTP(
 		const MTPUserStatus &status,
 		Data::LastseenStatus currentStatus) {
@@ -208,20 +235,34 @@ bool UserData::hasUnreadStories() const {
 	return flags() & Flag::HasUnreadStories;
 }
 
+bool UserData::hasActiveVideoStream() const {
+	return flags() & Flag::HasActiveVideoStream;
+}
+
 void UserData::setStoriesState(StoriesState state) {
 	Expects(state != StoriesState::Unknown);
 
 	const auto was = flags();
 	switch (state) {
 	case StoriesState::None:
-		_flags.remove(Flag::HasActiveStories | Flag::HasUnreadStories);
+		_flags.remove(Flag::HasActiveStories
+			| Flag::HasUnreadStories
+			| Flag::HasActiveVideoStream);
 		break;
 	case StoriesState::HasRead:
-		_flags.set(
-			(flags() & ~Flag::HasUnreadStories) | Flag::HasActiveStories);
+		_flags.set(Flag::HasActiveStories
+			| (was
+				& ~(Flag::HasUnreadStories | Flag::HasActiveVideoStream)));
 		break;
 	case StoriesState::HasUnread:
-		_flags.add(Flag::HasActiveStories | Flag::HasUnreadStories);
+		_flags.set((was & ~Flag::HasActiveVideoStream)
+			| Flag::HasActiveStories
+			| Flag::HasUnreadStories);
+		break;
+	case StoriesState::HasVideoStream:
+		_flags.set((was & ~Flag::HasUnreadStories)
+			| Flag::HasActiveStories
+			| Flag::HasActiveVideoStream);
 		break;
 	}
 	if (flags() != was) {
@@ -471,12 +512,43 @@ void UserData::setAccessHash(uint64 accessHash) {
 }
 
 void UserData::setFlags(UserDataFlags which) {
-	if ((which & UserDataFlag::Deleted)
-		!= (flags() & UserDataFlag::Deleted)) {
+	if (!isBot()) {
+		which &= ~Flag::Forum;
+	}
+	const auto diff = flags() ^ which;
+	if (diff & Flag::Deleted) {
 		invalidateEmptyUserpic();
 	}
-	_flags.set((flags() & UserDataFlag::Self)
-		| (which & ~UserDataFlag::Self));
+	// Let Data::Forum live till the end of _flags.set.
+	// That way the data can be used in changes handler.
+	// Example: render frame for forum auto-closing animation.
+	const auto takenForum = (botInfo
+		&& (diff & Flag::Forum)
+		&& !(which & Flag::Forum))
+		? botInfo->takeForumData()
+		: nullptr;
+	if ((diff & Flag::Forum) && (which & Flag::Forum)) {
+		if (const auto info = botInfo.get()) {
+			info->ensureForum(this);
+		}
+	}
+	_flags.set((flags() & Flag::Self) | (which & ~Flag::Self));
+	if (diff & Flag::Forum) {
+		if (const auto history = this->owner().historyLoaded(this)) {
+			if (diff & Flag::Forum) {
+				Core::App().notifications().clearFromHistory(history);
+				history->updateChatListEntryHeight();
+				if (history->inChatList()) {
+					if (const auto forum = this->forum()) {
+						forum->preloadTopics();
+					}
+				}
+			}
+		}
+	}
+	if (const auto raw = takenForum.get()) {
+		owner().forumIcons().clearUserpicsReset(raw);
+	}
 }
 
 void UserData::addFlags(UserDataFlags which) {
@@ -707,6 +779,17 @@ void UserData::setDisallowedGiftTypes(Api::DisallowedGiftTypes types) {
 	}
 }
 
+const TextWithEntities &UserData::note() const {
+	return _note;
+}
+
+void UserData::setNote(const TextWithEntities &note) {
+	if (_note != note) {
+		_note = note;
+		session().changes().peerUpdated(this, UpdateFlag::ContactNote);
+	}
+}
+
 namespace Data {
 
 void ApplyUserUpdate(not_null<UserData*> user, const MTPDuserFull &update) {
@@ -834,7 +917,7 @@ void ApplyUserUpdate(not_null<UserData*> user, const MTPDuserFull &update) {
 				}
 				creditsLoadLifetime->destroy();
 			});
-			base::timer_once(kTimeout) | rpl::start_with_next([=] {
+			base::timer_once(kTimeout) | rpl::on_next([=] {
 				creditsLoadLifetime->destroy();
 			}, *creditsLoadLifetime);
 			const auto currencyLoadLifetime
@@ -847,13 +930,13 @@ void ApplyUserUpdate(not_null<UserData*> user, const MTPDuserFull &update) {
 				}
 				currencyLoadLifetime->destroy();
 			};
-			currencyLoad->request() | rpl::start_with_error_done(
+			currencyLoad->request() | rpl::on_error_done(
 				[=](const QString &error) {
 					apply(CreditsAmount(0, CreditsType::Ton));
 				},
 				[=] { apply(currencyLoad->data().currentBalance); },
 				*currencyLoadLifetime);
-			base::timer_once(kTimeout) | rpl::start_with_next([=] {
+			base::timer_once(kTimeout) | rpl::on_next([=] {
 				currencyLoadLifetime->destroy();
 			}, *currencyLoadLifetime);
 		}
@@ -907,6 +990,9 @@ void ApplyUserUpdate(not_null<UserData*> user, const MTPDuserFull &update) {
 			| (data.is_disallow_premium_gifts()
 				? Api::DisallowedGiftType::Premium
 				: Api::DisallowedGiftType())
+			| (data.is_disallow_stargifts_from_channels()
+				? Api::DisallowedGiftType::FromChannels
+				: Api::DisallowedGiftType())
 			| (update.is_display_gifts_button()
 				? Api::DisallowedGiftType::SendHide
 				: Api::DisallowedGiftType()));
@@ -920,6 +1006,17 @@ void ApplyUserUpdate(not_null<UserData*> user, const MTPDuserFull &update) {
 	user->owner().stories().apply(user, update.vstories());
 	user->owner().savedMusic().apply(user, update.vsaved_music());
 
+	if (const auto note = update.vnote()) {
+		user->setNote(TextWithEntities{
+			qs(note->data().vtext()),
+			Api::EntitiesFromMTP(
+				&user->session(),
+				note->data().ventities().v)
+		});
+	} else {
+		user->setNote(TextWithEntities());
+	}
+
 	user->fullUpdated();
 }
 
