@@ -321,7 +321,7 @@ void NotifySettings::updateLocal(not_null<Thread*> thread) {
 		auto &lifetime = _mutedTopics.emplace(
 			topic,
 			rpl::lifetime()).first->second;
-		topic->destroyed() | rpl::start_with_next([=] {
+		topic->destroyed() | rpl::on_next([=] {
 			_mutedTopics.erase(topic);
 		}, lifetime);
 		unmuteByFinishedDelayed(changesIn);
@@ -385,7 +385,7 @@ void NotifySettings::cacheSound(const std::optional<NotifySound> &sound) {
 	}
 	// Not requested yet.
 	_owner->session().api().ringtones().listUpdates(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		for (const auto id : base::take(_ringtones.pendingIds)) {
 			cacheSound(id);
 		}
