@@ -269,7 +269,7 @@ TextWithEntities GenerateAdminChangeText(
 		tr::now,
 		lt_user,
 		user,
-		Ui::Text::WithEntities);
+		tr::marked);
 
 	const auto useInviteLinkPhrase = channel->isMegagroup()
 		&& channel->anyoneCanAddMembers();
@@ -296,12 +296,6 @@ TextWithEntities GenerateAdminChangeText(
 	phraseMap[Flag::InviteByLinkOrAdd] = invitePhrase;
 	phraseMap[Flag::ManageCall] = callPhrase;
 
-	if (!channel->isMegagroup()) {
-		// Don't display "Ban users" changes in channels.
-		newRights.flags &= ~Flag::BanUsers;
-		prevRights.flags &= ~Flag::BanUsers;
-	}
-
 	const auto changes = CollectChanges(
 		phraseMap,
 		newRights.flags,
@@ -362,7 +356,7 @@ TextWithEntities GeneratePermissionsChangeText(
 			tr::now,
 			lt_user,
 			user,
-			Ui::Text::WithEntities);
+			tr::marked);
 	} else if (newFlags == 0
 		&& (prevFlags & Flag::ViewMessages)
 		&& !peerIsUser(participantId)) {
@@ -370,7 +364,7 @@ TextWithEntities GeneratePermissionsChangeText(
 			tr::now,
 			lt_user,
 			user,
-			Ui::Text::WithEntities);
+			tr::marked);
 	}
 	const auto untilText = indefinitely
 		? tr::lng_admin_log_restricted_forever(tr::now)
@@ -384,7 +378,7 @@ TextWithEntities GeneratePermissionsChangeText(
 		user,
 		lt_until,
 		TextWithEntities { untilText },
-		Ui::Text::WithEntities);
+		tr::marked);
 	const auto changes = GeneratePermissionsChangeText(newRights, prevRights);
 	if (!changes.isEmpty()) {
 		result.text.append('\n' + changes);
@@ -432,7 +426,7 @@ TextWithEntities GenerateInviteLinkLink(const MTPExportedChatInvite &data) {
 	const auto text = GenerateInviteLinkText(data);
 	return text.endsWith(Ui::kQEllipsis)
 		? TextWithEntities{ .text = text }
-		: Ui::Text::Link(text, InternalInviteLinkUrl(data));
+		: tr::link(text, InternalInviteLinkUrl(data));
 }
 
 TextWithEntities GenerateInviteLinkChangeText(
@@ -450,7 +444,7 @@ TextWithEntities GenerateInviteLinkChangeText(
 		tr::now,
 		lt_link,
 		link,
-		Ui::Text::WithEntities);
+		tr::marked);
 	result.text.append('\n');
 
 	const auto label = [](const MTPExportedChatInvite &link) {
@@ -572,7 +566,7 @@ auto GenerateParticipantString(
 		name,
 		lt_mention,
 		mention,
-		Ui::Text::WithEntities);
+		tr::marked);
 }
 
 auto GenerateParticipantChangeText(
@@ -617,7 +611,7 @@ auto GenerateParticipantChangeText(
 			tr::now,
 			lt_user,
 			user,
-			Ui::Text::WithEntities);
+			tr::marked);
 	};
 
 	auto result = [&] {
@@ -639,7 +633,7 @@ auto GenerateParticipantChangeText(
 				tr::now,
 				lt_user,
 				user,
-				Ui::Text::WithEntities);
+				tr::marked);
 		}
 		case Api::ChatParticipant::Type::Admin: {
 			const auto user = GenerateParticipantString(
@@ -724,7 +718,7 @@ TextWithEntities GenerateDefaultBannedRightsChangeText(
 		not_null<ChannelData*> channel,
 		const MTPForumTopic &topic) {
 	return topic.match([&](const MTPDforumTopic &data) {
-		return Ui::Text::Link(
+		return tr::link(
 			Data::ForumTopicIconWithTitle(
 				data.vid().v,
 				data.vicon_emoji_id().value_or_empty(),
@@ -857,7 +851,7 @@ void GenerateItems(
 
 	const auto fromName = from->name();
 	const auto fromLink = from->createOpenLink();
-	const auto fromLinkText = Ui::Text::Link(fromName, QString());
+	const auto fromLinkText = tr::link(fromName, QString());
 
 	const auto addSimpleServiceMessage = [&](
 			const TextWithEntities &text,
@@ -885,7 +879,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_title,
 				{ .text = qs(action.vnew_value()) },
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(std::move(text));
 	};
 
@@ -912,7 +906,7 @@ void GenerateItems(
 			: (newValue.isEmpty()
 				? tr::lng_admin_log_removed_description_channel
 				: tr::lng_admin_log_changed_description_channel)
-			)(tr::now, lt_from, fromLinkText, Ui::Text::WithEntities);
+			)(tr::now, lt_from, fromLinkText, tr::marked);
 		addSimpleServiceMessage(text);
 
 		const auto body = makeSimpleTextMessage(
@@ -937,7 +931,7 @@ void GenerateItems(
 			: (newValue.isEmpty()
 				? tr::lng_admin_log_removed_link_channel
 				: tr::lng_admin_log_changed_link_channel)
-			)(tr::now, lt_from, fromLinkText, Ui::Text::WithEntities);
+			)(tr::now, lt_from, fromLinkText, tr::marked);
 		addSimpleServiceMessage(text);
 
 		const auto body = makeSimpleTextMessage(newValue.isEmpty()
@@ -966,7 +960,7 @@ void GenerateItems(
 					tr::now,
 					lt_from,
 					fromLinkText,
-					Ui::Text::WithEntities);
+					tr::marked);
 			addSimpleServiceMessage(text, MsgId(), photo);
 		}, [&](const MTPDphotoEmpty &data) {
 			const auto text = (channel->isMegagroup()
@@ -975,7 +969,7 @@ void GenerateItems(
 					tr::now,
 					lt_from,
 					fromLinkText,
-					Ui::Text::WithEntities);
+					tr::marked);
 			addSimpleServiceMessage(text);
 		});
 	};
@@ -988,7 +982,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1000,7 +994,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1014,7 +1008,7 @@ void GenerateItems(
 					tr::now,
 					lt_from,
 					fromLinkText,
-					Ui::Text::WithEntities);
+					tr::marked);
 			addSimpleServiceMessage(text, realId);
 
 			addPart(
@@ -1029,7 +1023,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		});
 	};
@@ -1067,7 +1061,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text, realId);
 
 		const auto body = history->createItem(
@@ -1095,7 +1089,7 @@ void GenerateItems(
 			tr::now,
 			lt_from,
 			fromLinkText,
-			Ui::Text::WithEntities);
+			tr::marked);
 		addSimpleServiceMessage(text, realId);
 
 		addPart(
@@ -1114,7 +1108,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1125,7 +1119,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1165,7 +1159,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		} else {
 			const auto text = tr::lng_admin_log_changed_stickers_group(
@@ -1173,10 +1167,10 @@ void GenerateItems(
 				lt_from,
 				fromLinkText,
 				lt_sticker_set,
-				Ui::Text::Link(
+				tr::link(
 					tr::lng_admin_log_changed_stickers_set(tr::now),
 					QString()),
-				Ui::Text::WithEntities);
+				tr::marked);
 			const auto setLink = std::make_shared<LambdaClickHandler>([=](
 					ClickContext context) {
 				const auto my = context.other.value<ClickHandlerContext>();
@@ -1209,7 +1203,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		} else {
 			const auto text = tr::lng_admin_log_changed_emoji_group(
@@ -1217,10 +1211,10 @@ void GenerateItems(
 				lt_from,
 				fromLinkText,
 				lt_sticker_set,
-				Ui::Text::Link(
+				tr::link(
 					tr::lng_admin_log_changed_emoji_set(tr::now),
 					QString()),
-				Ui::Text::WithEntities);
+				tr::marked);
 			const auto setLink = std::make_shared<LambdaClickHandler>([=](
 					ClickContext context) {
 				const auto my = context.other.value<ClickHandlerContext>();
@@ -1254,7 +1248,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1273,7 +1267,7 @@ void GenerateItems(
 			tr::now,
 			lt_from,
 			fromLinkText,
-			Ui::Text::WithEntities);
+			tr::marked);
 		addSimpleServiceMessage(text, realId);
 
 		addPart(
@@ -1295,7 +1289,7 @@ void GenerateItems(
 					tr::now,
 					lt_from,
 					fromLinkText,
-					Ui::Text::WithEntities);
+					tr::marked);
 			addSimpleServiceMessage(text);
 		} else {
 			const auto text = (broadcast
@@ -1305,8 +1299,8 @@ void GenerateItems(
 					lt_from,
 					fromLinkText,
 					lt_chat,
-					Ui::Text::Link(now->name(), QString()),
-					Ui::Text::WithEntities);
+					tr::link(now->name(), QString()),
+					tr::marked);
 			const auto chatLink = std::make_shared<LambdaClickHandler>([=] {
 				if (const auto window = now->session().tryResolveWindow()) {
 					window->showPeerHistory(now);
@@ -1329,7 +1323,7 @@ void GenerateItems(
 			const auto address = qs(data.vaddress());
 			const auto link = data.vgeo_point().match([&](
 					const MTPDgeoPoint &data) {
-				return Ui::Text::Link(
+				return tr::link(
 					address,
 					LocationClickHandler::Url(Data::LocationPoint(data)));
 			}, [&](const MTPDgeoPointEmpty &) {
@@ -1341,14 +1335,14 @@ void GenerateItems(
 				fromLinkText,
 				lt_address,
 				link,
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		}, [&](const MTPDchannelLocationEmpty &) {
 			const auto text = tr::lng_admin_log_removed_location_chat(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		});
 	};
@@ -1364,14 +1358,14 @@ void GenerateItems(
 				fromLinkText,
 				lt_duration,
 				{ .text = duration },
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		} else {
 			const auto text = tr::lng_admin_log_removed_slow_mode(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		}
 	};
@@ -1383,7 +1377,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1394,7 +1388,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1423,7 +1417,7 @@ void GenerateItems(
 		const auto participantPeer = groupCallParticipantPeer(
 			data.vparticipant());
 		const auto participantPeerLink = participantPeer->createOpenLink();
-		const auto participantPeerLinkText = Ui::Text::Link(
+		const auto participantPeerLinkText = tr::link(
 			participantPeer->name(),
 			QString());
 		const auto text = (broadcast
@@ -1434,7 +1428,7 @@ void GenerateItems(
 			fromLinkText,
 			lt_user,
 			participantPeerLinkText,
-			Ui::Text::WithEntities);
+			tr::marked);
 		addServiceMessageWithLink(text, participantPeerLink);
 	};
 
@@ -1442,7 +1436,7 @@ void GenerateItems(
 		const auto participantPeer = groupCallParticipantPeer(
 			data.vparticipant());
 		const auto participantPeerLink = participantPeer->createOpenLink();
-		const auto participantPeerLinkText = Ui::Text::Link(
+		const auto participantPeerLinkText = tr::link(
 			participantPeer->name(),
 			QString());
 		const auto text = (broadcast
@@ -1453,7 +1447,7 @@ void GenerateItems(
 			fromLinkText,
 			lt_user,
 			participantPeerLinkText,
-			Ui::Text::WithEntities);
+			tr::marked);
 		addServiceMessageWithLink(text, participantPeerLink);
 	};
 
@@ -1469,7 +1463,7 @@ void GenerateItems(
 			tr::now,
 			lt_from,
 			fromLinkText,
-			Ui::Text::WithEntities);
+			tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1510,7 +1504,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_link,
 				GenerateInviteLinkLink(data.vinvite()),
-				Ui::Text::WithEntities),
+				tr::marked),
 			data.vinvite());
 	};
 
@@ -1522,7 +1516,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_link,
 				GenerateInviteLinkLink(data.vinvite()),
-				Ui::Text::WithEntities),
+				tr::marked),
 			data.vinvite());
 	};
 
@@ -1534,7 +1528,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_link,
 				GenerateInviteLinkLink(data.vinvite()),
-				Ui::Text::WithEntities),
+				tr::marked),
 			data.vinvite());
 	};
 
@@ -1549,7 +1543,7 @@ void GenerateItems(
 		const auto participantPeer = groupCallParticipantPeer(
 			data.vparticipant());
 		const auto participantPeerLink = participantPeer->createOpenLink();
-		const auto participantPeerLinkText = Ui::Text::Link(
+		const auto participantPeerLinkText = tr::link(
 			participantPeer->name(),
 			QString());
 		const auto volume = data.vparticipant().match([&](
@@ -1567,7 +1561,7 @@ void GenerateItems(
 				participantPeerLinkText,
 				lt_percent,
 				{ .text = volumeText },
-				Ui::Text::WithEntities);
+				tr::marked);
 		addServiceMessageWithLink(text, participantPeerLink);
 	};
 
@@ -1587,7 +1581,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_duration,
 				wrap(now),
-				Ui::Text::WithEntities)
+				tr::marked)
 			: !now
 			? tr::lng_admin_log_messages_ttl_removed(
 				tr::now,
@@ -1595,7 +1589,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_duration,
 				wrap(was),
-				Ui::Text::WithEntities)
+				tr::marked)
 			: tr::lng_admin_log_messages_ttl_changed(
 				tr::now,
 				lt_from,
@@ -1604,7 +1598,7 @@ void GenerateItems(
 				wrap(was),
 				lt_duration,
 				wrap(now),
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1620,8 +1614,8 @@ void GenerateItems(
 					lt_from,
 					fromLinkText,
 					lt_user,
-					Ui::Text::Link(user->name(), QString()),
-					Ui::Text::WithEntities)
+					tr::link(user->name(), QString()),
+					tr::marked)
 			: (channel->isMegagroup()
 				? tr::lng_admin_log_participant_approved_by_link
 				: tr::lng_admin_log_participant_approved_by_link_channel)(
@@ -1631,8 +1625,8 @@ void GenerateItems(
 					lt_link,
 					linkText,
 					lt_user,
-					Ui::Text::Link(user->name(), QString()),
-					Ui::Text::WithEntities);
+					tr::link(user->name(), QString()),
+					tr::marked);
 		addInviteLinkServiceMessage(
 			text,
 			data.vinvite(),
@@ -1647,7 +1641,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1657,7 +1651,7 @@ void GenerateItems(
 			tr::now,
 			lt_from,
 			fromLinkText,
-			Ui::Text::WithEntities);
+			tr::marked);
 		addSimpleServiceMessage(text, realId);
 
 		addPart(
@@ -1677,7 +1671,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		}, [&](const MTPDchatReactionsSome &data) {
 			using namespace Window::Notifications;
 			auto list = TextWithEntities();
@@ -1695,7 +1689,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_emoji,
 				list,
-				Ui::Text::WithEntities);
+				tr::marked);
 		}, [&](const MTPDchatReactionsAll &data) {
 			return (data.is_allow_custom()
 				? tr::lng_admin_log_reactions_allowed_all
@@ -1703,7 +1697,7 @@ void GenerateItems(
 					tr::now,
 					lt_from,
 					fromLinkText,
-					Ui::Text::WithEntities);
+					tr::marked);
 		});
 		addSimpleServiceMessage(text);
 	};
@@ -1749,7 +1743,7 @@ void GenerateItems(
 							tr::now,
 							lt_from,
 							fromLinkText,
-							Ui::Text::WithEntities));
+							tr::marked));
 					const auto body = makeSimpleTextMessage(list(newValue));
 					body->addLogEntryOriginal(
 						id,
@@ -1778,7 +1772,7 @@ void GenerateItems(
 					fromLinkText,
 					lt_link,
 					{ changed },
-					Ui::Text::WithEntities));
+					tr::marked));
 			return;
 		}
 		// Probably will never happen.
@@ -1804,7 +1798,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1816,7 +1810,7 @@ void GenerateItems(
 			fromLinkText,
 			lt_topic,
 			topicLink,
-			Ui::Text::WithEntities));
+			tr::marked));
 	};
 
 	const auto createEditTopic = [&](const LogEditTopic &data) {
@@ -1831,7 +1825,7 @@ void GenerateItems(
 				prevLink,
 				lt_new_topic,
 				nowLink,
-				Ui::Text::WithEntities));
+				tr::marked));
 		}
 		const auto wasClosed = IsTopicClosed(data.vprev_topic());
 		const auto nowClosed = IsTopicClosed(data.vnew_topic());
@@ -1844,7 +1838,7 @@ void GenerateItems(
 					fromLinkText,
 					lt_topic,
 					nowLink,
-					Ui::Text::WithEntities));
+					tr::marked));
 		}
 		const auto wasHidden = IsTopicHidden(data.vprev_topic());
 		const auto nowHidden = IsTopicHidden(data.vnew_topic());
@@ -1857,7 +1851,7 @@ void GenerateItems(
 					fromLinkText,
 					lt_topic,
 					nowLink,
-					Ui::Text::WithEntities));
+					tr::marked));
 		}
 	};
 
@@ -1872,7 +1866,7 @@ void GenerateItems(
 			fromLinkText,
 			lt_topic,
 			topicLink,
-			Ui::Text::WithEntities));
+			tr::marked));
 	};
 
 	const auto createPinTopic = [&](const LogPinTopic &data) {
@@ -1884,7 +1878,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_topic,
 				topicLink,
-				Ui::Text::WithEntities));
+				tr::marked));
 		} else if (const auto &previous = data.vprev_topic()) {
 			auto topicLink = GenerateTopicLink(channel, *previous);
 			addSimpleServiceMessage(tr::lng_admin_log_topics_unpinned(
@@ -1893,7 +1887,7 @@ void GenerateItems(
 				fromLinkText,
 				lt_topic,
 				topicLink,
-				Ui::Text::WithEntities));
+				tr::marked));
 		}
 	};
 
@@ -1905,7 +1899,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -1936,7 +1930,7 @@ void GenerateItems(
 				{ '#' + QString::number(wrap(prevColor) + 1) },
 				lt_color,
 				{ '#' + QString::number(wrap(nextColor) + 1) },
-				Ui::Text::WithEntities);
+				tr::marked);
 			addSimpleServiceMessage(text);
 		}
 		const auto prevEmoji = (was.type() == mtpc_peerColor)
@@ -1954,7 +1948,7 @@ void GenerateItems(
 					lt_emoji,
 					Ui::Text::SingleCustomEmoji(
 						Data::SerializeCustomEmojiId(nextEmoji)),
-					Ui::Text::WithEntities)
+					tr::marked)
 				: !nextEmoji
 				? removeEmoji(
 					tr::now,
@@ -1963,7 +1957,7 @@ void GenerateItems(
 					lt_emoji,
 					Ui::Text::SingleCustomEmoji(
 						Data::SerializeCustomEmojiId(prevEmoji)),
-					Ui::Text::WithEntities)
+					tr::marked)
 				: changeEmoji(
 					tr::now,
 					lt_from,
@@ -1974,7 +1968,7 @@ void GenerateItems(
 					lt_emoji,
 					Ui::Text::SingleCustomEmoji(
 						Data::SerializeCustomEmojiId(nextEmoji)),
-					Ui::Text::WithEntities);
+					tr::marked);
 			addSimpleServiceMessage(text);
 		}
 	};
@@ -2013,7 +2007,7 @@ void GenerateItems(
 			tr::now,
 			lt_from,
 			fromLinkText,
-			Ui::Text::WithEntities));
+			tr::marked));
 	};
 
 	const auto createChangeEmojiStatus = [&](const LogChangeEmojiStatus &data) {
@@ -2048,7 +2042,7 @@ void GenerateItems(
 					lt_date,
 					TextWithEntities{
 						langDateTime(base::unixtime::parse(nextUntil)) },
-					Ui::Text::WithEntities)
+					tr::marked)
 				: tr::lng_admin_log_set_status(
 					tr::now,
 					lt_from,
@@ -2056,7 +2050,7 @@ void GenerateItems(
 					lt_emoji,
 					Ui::Text::SingleCustomEmoji(
 						Data::SerializeCustomEmojiId(nextEmoji)),
-					Ui::Text::WithEntities))
+					tr::marked))
 			: !nextEmoji
 			? tr::lng_admin_log_removed_status(
 				tr::now,
@@ -2065,7 +2059,7 @@ void GenerateItems(
 				lt_emoji,
 				Ui::Text::SingleCustomEmoji(
 					Data::SerializeCustomEmojiId(prevEmoji)),
-				Ui::Text::WithEntities)
+				tr::marked)
 			: (nextUntil
 				? tr::lng_admin_log_change_status_until(
 					tr::now,
@@ -2080,7 +2074,7 @@ void GenerateItems(
 					lt_date,
 					TextWithEntities{
 						langDateTime(base::unixtime::parse(nextUntil)) },
-					Ui::Text::WithEntities)
+					tr::marked)
 				: tr::lng_admin_log_change_status(
 					tr::now,
 					lt_from,
@@ -2091,7 +2085,7 @@ void GenerateItems(
 					lt_emoji,
 					Ui::Text::SingleCustomEmoji(
 						Data::SerializeCustomEmojiId(nextEmoji)),
-					Ui::Text::WithEntities));
+					tr::marked));
 		addSimpleServiceMessage(text);
 	};
 
@@ -2103,7 +2097,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
@@ -2116,7 +2110,7 @@ void GenerateItems(
 		}
 		const auto participantPeer = channel->owner().peer(participant.id());
 		const auto participantPeerLink = participantPeer->createOpenLink();
-		const auto participantPeerLinkText = Ui::Text::Link(
+		const auto participantPeerLinkText = tr::link(
 			participantPeer->name(),
 			QString());
 		const auto parsed = base::unixtime::parse(
@@ -2128,7 +2122,7 @@ void GenerateItems(
 				participantPeerLinkText,
 				lt_date,
 				{ langDateTimeFull(parsed) },
-				Ui::Text::WithEntities),
+				tr::marked),
 			participantPeerLink);
 	};
 
@@ -2140,7 +2134,7 @@ void GenerateItems(
 				tr::now,
 				lt_from,
 				fromLinkText,
-				Ui::Text::WithEntities);
+				tr::marked);
 		addSimpleServiceMessage(text);
 	};
 
