@@ -223,7 +223,7 @@ std::optional<SendPaymentDetails> ComputePaymentDetails(
 
 bool SuggestPaymentDataReady(
 		not_null<PeerData*> peer,
-		SuggestPostOptions suggest) {
+		SuggestOptions suggest) {
 	if (!suggest.exists || !suggest.price() || peer->amMonoforumAdmin()) {
 		return true;
 	} else if (suggest.ton && !peer->session().credits().tonLoaded()) {
@@ -244,11 +244,11 @@ object_ptr<Ui::BoxContent> MakeSendErrorBox(
 	auto text = TextWithEntities();
 	if (withTitle) {
 		text.append(
-			Ui::Text::Bold(error.thread->chatListName())
+			tr::bold(error.thread->chatListName())
 		).append("\n\n");
 	}
 	if (error.error.boostsToLift) {
-		text.append(Ui::Text::Link(error.error.text));
+		text.append(tr::link(error.error.text));
 	} else {
 		text.append(error.error.text);
 	}
@@ -374,15 +374,15 @@ void ShowSendPaidConfirm(
 					lt_count,
 					stars / messages,
 					lt_name,
-					Ui::Text::Bold(singlePeer->shortName()),
-					Ui::Text::RichLangValue)
+					tr::bold(singlePeer->shortName()),
+					tr::rich)
 				: (usersOnly
 					? tr::lng_payment_confirm_users
 					: tr::lng_payment_confirm_chats)(
 						tr::now,
 						lt_count,
 						int(peers.size()),
-						Ui::Text::RichLangValue)).append(' ').append(
+						tr::rich)).append(' ').append(
 							tr::lng_payment_confirm_sure(
 								tr::now,
 								lt_count,
@@ -392,8 +392,8 @@ void ShowSendPaidConfirm(
 									tr::now,
 									lt_count,
 									stars,
-									Ui::Text::RichLangValue),
-								Ui::Text::RichLangValue)),
+									tr::rich),
+								tr::rich)),
 			.confirmed = proceed,
 			.confirmText = tr::lng_payment_confirm_button(
 				lt_count,
@@ -460,7 +460,7 @@ bool SendPaymentHelper::check(
 			peer->session().credits().loadedValue(
 			) | rpl::filter(
 				rpl::mappers::_1
-			) | rpl::take(1) | rpl::start_with_next([=] {
+			) | rpl::take(1) | rpl::on_next([=] {
 				if (const auto callback = base::take(_resend)) {
 					callback();
 				}
@@ -472,7 +472,7 @@ bool SendPaymentHelper::check(
 			peer->session().credits().tonLoadedValue(
 			) | rpl::filter(
 				rpl::mappers::_1
-			) | rpl::take(1) | rpl::start_with_next([=] {
+			) | rpl::take(1) | rpl::on_next([=] {
 				if (const auto callback = base::take(_resend)) {
 					callback();
 				}
@@ -482,7 +482,7 @@ bool SendPaymentHelper::check(
 		peer->session().changes().peerUpdates(
 			peer,
 			Data::PeerUpdate::Flag::FullInfo
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			if (const auto callback = base::take(_resend)) {
 				callback();
 			}
@@ -1032,14 +1032,14 @@ PreparedServiceText GenerateJoinedText(
 			: tr::lng_action_add_you)(
 				tr::now,
 				lt_from,
-				Ui::Text::Link(inviter->name(), QString()),
-				Ui::Text::WithEntities);
+				tr::link(inviter->name(), QString()),
+				tr::marked);
 		return result;
 	} else if (history->peer->isMegagroup()) {
 		if (viaRequest) {
 			return { tr::lng_action_you_joined_by_request(
 				tr::now,
-				Ui::Text::WithEntities) };
+				tr::marked) };
 		}
 		auto self = history->session().user();
 		auto result = PreparedServiceText();
@@ -1047,15 +1047,15 @@ PreparedServiceText GenerateJoinedText(
 		result.text = tr::lng_action_user_joined(
 			tr::now,
 			lt_from,
-			Ui::Text::Link(self->name(), QString()),
-			Ui::Text::WithEntities);
+			tr::link(self->name(), QString()),
+			tr::marked);
 		return result;
 	}
 	return { viaRequest
 		? tr::lng_action_you_joined_by_request_channel(
 			tr::now,
-			Ui::Text::WithEntities)
-		: tr::lng_action_you_joined(tr::now, Ui::Text::WithEntities) };
+			tr::marked)
+		: tr::lng_action_you_joined(tr::now, tr::marked) };
 }
 
 not_null<HistoryItem*> GenerateJoinedMessage(
@@ -1269,14 +1269,14 @@ void ShowTrialTranscribesToast(int left, TimeId until) {
 			left,
 			lt_date,
 			{ date },
-			Ui::Text::WithEntities)
+			tr::marked)
 		: tr::lng_audio_transcribe_trials_over(
 			tr::now,
 			lt_date,
-			Ui::Text::Bold(date),
+			tr::bold(date),
 			lt_link,
-			Ui::Text::Link(tr::lng_settings_privacy_premium_link(tr::now)),
-			Ui::Text::WithEntities);
+			tr::link(tr::lng_settings_privacy_premium_link(tr::now)),
+			tr::marked);
 	window->uiShow()->showToast(Ui::Toast::Config{
 		.text = text,
 		.filter = filter,
