@@ -131,7 +131,7 @@ namespace {
 		st::historyContactStatusButton.ripple);
 	const auto raw = result.data();
 	raw->paintRequest(
-	) | rpl::start_with_next([=, &icon] {
+	) | rpl::on_next([=, &icon] {
 		auto p = QPainter(raw);
 		p.fillRect(raw->rect(), st::historyContactStatusButton.bgColor);
 		raw->paintRipple(p, 0, 0);
@@ -263,7 +263,7 @@ ContactStatus::Bar::Bar(
 , _emojiStatusShadow(this) {
 	_requestChatInfo->setAttribute(Qt::WA_TransparentForMouseEvents);
 	_emojiStatusInfo->paintRequest(
-	) | rpl::start_with_next([=, raw = _emojiStatusInfo.data()](QRect clip) {
+	) | rpl::on_next([=, raw = _emojiStatusInfo.data()](QRect clip) {
 		_emojiStatusRepaintScheduled = false;
 		QPainter(raw).fillRect(clip, st::historyComposeButtonBg);
 	}, lifetime());
@@ -301,9 +301,9 @@ void ContactStatus::Bar::showState(
 				lt_emoji,
 				status,
 				lt_link,
-				Ui::Text::Link(
+				tr::link(
 					tr::lng_new_contact_about_status_link(tr::now)),
-				Ui::Text::WithEntities),
+				tr::marked),
 			context);
 		_emojiStatusInfo->entity()->overrideLinkClickHandler([=] {
 			_emojiStatusClicks.fire({});
@@ -325,10 +325,10 @@ void ContactStatus::Bar::showState(
 			: tr::lng_new_contact_from_request_group)(
 			tr::now,
 			lt_user,
-			Ui::Text::Bold(_name),
+			tr::bold(_name),
 			lt_name,
-			Ui::Text::Bold(state.requestChatName),
-			Ui::Text::WithEntities));
+			tr::bold(state.requestChatName),
+			tr::marked));
 	resizeToWidth(width());
 }
 
@@ -499,12 +499,12 @@ SlidingBar::SlidingBar(
 
 void SlidingBar::setup(not_null<Ui::RpWidget*> parent) {
 	parent->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		_wrapped.resizeToWidth(width);
 	}, _wrapped.lifetime());
 
 	_wrapped.geometryValue(
-	) | rpl::start_with_next([=](QRect geometry) {
+	) | rpl::on_next([=](QRect geometry) {
 		_shadow.setGeometry(
 			geometry.x(),
 			geometry.y() + geometry.height(),
@@ -640,8 +640,8 @@ void ContactStatus::setupState(not_null<PeerData*> peer, bool showInForum) {
 		PeerCustomStatus(peer),
 		((channel && !showInForum)
 			? Data::PeerFlagValue(channel, ChannelData::Flag::Forum)
-			: (rpl::single(false) | rpl::type_erased()))
-	) | rpl::start_with_next([=](
+			: (rpl::single(false) | rpl::type_erased))
+	) | rpl::on_next([=](
 			State state,
 			TextWithEntities status,
 			bool hiddenByForum) {
@@ -672,14 +672,14 @@ void ContactStatus::setupHandlers(not_null<PeerData*> peer) {
 
 void ContactStatus::setupAddHandler(not_null<UserData*> user) {
 	_inner->addClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_controller->window().show(Box(EditContactBox, _controller, user));
 	}, _bar.lifetime());
 }
 
 void ContactStatus::setupBlockHandler(not_null<UserData*> user) {
 	_inner->blockClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_controller->window().show(Box(
 			Window::PeerMenuBlockUserBox,
 			&_controller->window(),
@@ -691,7 +691,7 @@ void ContactStatus::setupBlockHandler(not_null<UserData*> user) {
 
 void ContactStatus::setupShareHandler(not_null<UserData*> user) {
 	_inner->shareClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		const auto show = _controller->uiShow();
 		const auto share = [=](Fn<void()> &&close) {
 			user->setBarSettings(0);
@@ -710,11 +710,11 @@ void ContactStatus::setupShareHandler(not_null<UserData*> user) {
 			.text = tr::lng_new_contact_share_sure(
 				tr::now,
 				lt_phone,
-				Ui::Text::WithEntities(
+				tr::marked(
 					Ui::FormatPhone(user->session().user()->phone())),
 				lt_user,
-				Ui::Text::Bold(user->name()),
-				Ui::Text::WithEntities),
+				tr::bold(user->name()),
+				tr::marked),
 			.confirmed = share,
 			.confirmText = tr::lng_box_ok(),
 		}));
@@ -723,7 +723,7 @@ void ContactStatus::setupShareHandler(not_null<UserData*> user) {
 
 void ContactStatus::setupUnarchiveHandler(not_null<PeerData*> peer) {
 	_inner->unarchiveClicks(
-	) | rpl::start_with_next([=, show = _controller->uiShow()] {
+	) | rpl::on_next([=, show = _controller->uiShow()] {
 		using namespace Window;
 		ToggleHistoryArchived(show, peer->owner().history(peer), false);
 		peer->owner().notifySettings().resetToDefault(peer);
@@ -738,7 +738,7 @@ void ContactStatus::setupUnarchiveHandler(not_null<PeerData*> peer) {
 
 void ContactStatus::setupReportHandler(not_null<PeerData*> peer) {
 	_inner->reportClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Expects(!peer->isUser());
 
 		const auto show = _controller->uiShow();
@@ -781,7 +781,7 @@ void ContactStatus::setupCloseHandler(not_null<PeerData*> peer) {
 	_inner->closeClicks(
 	) | rpl::filter([=] {
 		return !(*request);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		peer->setBarSettings(0);
 		*request = peer->session().api().request(
 			MTPmessages_HidePeerSettingsBar(peer->input)
@@ -794,7 +794,7 @@ void ContactStatus::setupRequestInfoHandler(not_null<PeerData*> peer) {
 	_inner->requestInfoClicks(
 	) | rpl::filter([=] {
 		return !(*request);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		_controller->show(Box([=](not_null<Ui::GenericBox*> box) {
 			box->setTitle((_state.requestChatIsBroadcast
 				? tr::lng_from_request_title_channel
@@ -804,12 +804,12 @@ void ContactStatus::setupRequestInfoHandler(not_null<PeerData*> peer) {
 				box,
 				tr::lng_from_request_body(
 					lt_name,
-					rpl::single(Ui::Text::Bold(_state.requestChatName)),
+					rpl::single(tr::bold(_state.requestChatName)),
 					lt_date,
-					rpl::single(langDateTimeFull(
+					rpl::single(tr::marked(langDateTimeFull(
 						base::unixtime::parse(_state.requestDate)
-					)) | Ui::Text::ToWithEntities(),
-					Ui::Text::WithEntities),
+					))),
+					tr::marked),
 				st::boxLabel));
 
 			box->addButton(tr::lng_from_request_understand(), [=] {
@@ -828,7 +828,7 @@ void ContactStatus::setupRequestInfoHandler(not_null<PeerData*> peer) {
 
 void ContactStatus::setupEmojiStatusHandler(not_null<PeerData*> peer) {
 	_inner->emojiStatusClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Settings::ShowEmojiStatusPremium(_controller, peer);
 	}, _bar.lifetime());
 }
@@ -1042,7 +1042,7 @@ void BusinessBotStatus::setupState(not_null<PeerData*> peer) {
 	}
 	PeerState(
 		peer
-	) | rpl::start_with_next([=](State state) {
+	) | rpl::on_next([=](State state) {
 		_state = state;
 		if (!state.bot) {
 			_bar.toggleContent(false);
@@ -1055,22 +1055,22 @@ void BusinessBotStatus::setupState(not_null<PeerData*> peer) {
 
 void BusinessBotStatus::setupHandlers(not_null<PeerData*> peer) {
 	_inner->pauseClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		peer->owner().chatbots().togglePaused(peer, true);
 	}, _bar.lifetime());
 
 	_inner->resumeClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		peer->owner().chatbots().togglePaused(peer, false);
 	}, _bar.lifetime());
 
 	_inner->removeClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		peer->owner().chatbots().removeFrom(peer);
 	}, _bar.lifetime());
 
 	_inner->manageClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		UrlClickHandler::Open(
 			_state.manageUrl,
 			QVariant::fromValue(ClickHandlerContext{
@@ -1110,8 +1110,10 @@ TopicReopenBar::TopicReopenBar(
 
 void TopicReopenBar::setupState() {
 	const auto channel = _topic->channel();
-	auto canToggle = (_topic->my() || channel->amCreator())
-		? (rpl::single(true) | rpl::type_erased())
+	auto canToggle = !channel
+		? (rpl::single(false) | rpl::type_erased)
+		: (_topic->my() || channel->amCreator())
+		? (rpl::single(true) | rpl::type_erased)
 		: channel->adminRightsValue(
 		) | rpl::map([=] { return _topic->canToggleClosed(); });
 
@@ -1120,7 +1122,7 @@ void TopicReopenBar::setupState() {
 			_topic,
 			Data::TopicUpdate::Flag::Closed),
 		std::move(canToggle)
-	) | rpl::start_with_next([=](const auto &, bool can) {
+	) | rpl::on_next([=](const auto &, bool can) {
 		_bar.toggleContent(can && _topic->closed());
 	}, _bar.lifetime());
 }
@@ -1165,7 +1167,7 @@ void PaysStatus::Bar::showState(State state) {
 		TextWithEntities{ _peer->shortName() },
 		lt_cost,
 		PaidSendButtonText(tr::now, state.perMessage),
-		Ui::Text::WithEntities));
+		tr::marked));
 	resizeToWidth(width());
 }
 
@@ -1207,7 +1209,7 @@ void PaysStatus::setupState() {
 	_user->session().changes().peerFlagsValue(
 		_user,
 		Data::PeerUpdate::Flag::PaysPerMessage
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_state = State{ _user->paysPerMessage() };
 		if (_state.perMessage > 0) {
 			_inner->showState(_state);
@@ -1220,7 +1222,7 @@ void PaysStatus::setupState() {
 
 void PaysStatus::setupHandlers() {
 	_inner->removeClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Window::PeerMenuConfirmToggleFee(
 			_controller,
 			_paidAlready,
