@@ -1030,7 +1030,7 @@ TextWithEntities Reply::ComposePreviewName(
 				tr::now,
 				lt_title,
 				todolist->title,
-				Ui::Text::WithEntities);
+				tr::marked);
 		}
 	}
 	const auto toPeer = to->history()->peer;
@@ -1057,7 +1057,7 @@ TextWithEntities Reply::ComposePreviewName(
 			tr::now,
 			lt_name,
 			nameFull,
-			Ui::Text::WithEntities);
+			tr::marked);
 
 }
 
