@@ -388,7 +388,7 @@ TopBar::TopBar(
 	_peer->session().changes().peerFlagsValue(
 		_peer,
 		Data::PeerUpdate::Flag::OnlineStatus | Data::PeerUpdate::Flag::Members
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_statusLabel->refresh();
 	}, lifetime());
 
@@ -415,14 +415,14 @@ TopBar::TopBar(
 			std::move(badgeUpdates),
 			_botVerify->updated());
 	}
-	_title->naturalWidthValue() | rpl::start_with_next([=](int w) {
+	_title->naturalWidthValue() | rpl::on_next([=](int w) {
 		_title->resizeToWidth(w);
 	}, _title->lifetime());
 	badgeUpdates = rpl::merge(
 		std::move(badgeUpdates),
 		nameValue() | rpl::to_empty,
 		_backToggles.value() | rpl::to_empty);
-	std::move(badgeUpdates) | rpl::start_with_next([=] {
+	std::move(badgeUpdates) | rpl::on_next([=] {
 		updateLabelsPosition();
 	}, _title->lifetime());
 
@@ -434,7 +434,7 @@ TopBar::TopBar(
 			_peer,
 			Data::PeerUpdate::Flag::FullInfo
 				| Data::PeerUpdate::Flag::ChannelAmIn
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			setupActions(controller);
 		}, lifetime());
 	}
@@ -473,7 +473,7 @@ TopBar::TopBar(
 			_peer,
 			Data::PeerUpdate::Flag::EmojiStatus
 				| Data::PeerUpdate::Flag::ColorProfile) | rpl::to_empty
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (_pinnedToTopGiftsFirstTimeShowed) {
 			_peer->session().recentSharedGifts().clearLastRequestTime(_peer);
 			setupPinnedToTopGifts(controller);
@@ -484,7 +484,7 @@ TopBar::TopBar(
 
 	std::move(
 		descriptor.showFinished
-	) | rpl::take(1) | rpl::start_with_next([=] {
+	) | rpl::take(1) | rpl::on_next([=] {
 		setupPinnedToTopGifts(controller);
 	}, lifetime());
 
@@ -501,7 +501,8 @@ void TopBar::adjustColors(const std::optional<QColor> &edgeColor) {
 	};
 	const auto collectible = effectiveCollectible();
 	const auto shouldOverrideTitle = shouldOverride(_title->st().textFg);
-	const auto shouldOverrideStatus = shouldOverrideTitle; // shouldOverride(_status->st().textFg);
+	const auto shouldOverrideStatus = shouldOverrideTitle
+		|| shouldOverride(_status->st().textFg);
 	_title->setTextColorOverride(collectible
 		? collectible->textColor
 		: shouldOverrideTitle
@@ -539,7 +540,7 @@ void TopBar::adjustColors(const std::optional<QColor> &edgeColor) {
 		if (!_peer->isMegagroup() && !_topic) {
 			setupStatusWithRating();
 		}
-		_status->widthValue() | rpl::start_with_next([=] {
+		_status->widthValue() | rpl::on_next([=] {
 			updateStatusPosition(_progress.current());
 		}, _status->lifetime());
 		_statusLabel = std::make_unique<StatusLabel>(_status.data(), _peer);
@@ -697,20 +698,20 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 	const auto guard = gsl::finally([&] {
 		addMore();
 		style::PaletteChanged(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			const auto current = _edgeColor.current();
 			_edgeColor.force_assign(current);
 		}, _actions->lifetime());
 		_edgeColor.value() | rpl::map([=](std::optional<QColor> c) {
 			return mapActionStyle(c);
-		}) | rpl::start_with_next([=](
+		}) | rpl::on_next([=](
 				TopBarActionButtonStyle st) {
 			for (const auto &button : buttons) {
 				button->setStyle(st);
 			}
 		}, _actions->lifetime());
 		const auto padding = st::infoProfileTopBarActionButtonsPadding;
-		sizeValue() | rpl::start_with_next([=](const QSize &size) {
+		sizeValue() | rpl::on_next([=](const QSize &size) {
 			const auto ratio = float64(size.height())
 				/ (st::infoProfileTopBarActionButtonsHeight
 					+ st::infoLayerTopBarHeight);
@@ -748,7 +749,7 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 			tr::lng_profile_action_short_join(tr::now),
 			st::infoProfileTopBarActionJoin);
 		join->setClickedCallback([=] {
-			channel->owner().session().api().joinChannel(channel);
+			channel->session().api().joinChannel(channel);
 		});
 		buttons.push_back(join);
 		_actions->add(join);
@@ -785,7 +786,7 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 		(topic
 			? NotificationsEnabledValue(topic)
 			: NotificationsEnabledValue(peer)
-		) | rpl::start_with_next([=](bool enabled) {
+		) | rpl::on_next([=](bool enabled) {
 			notifications->toggle(enabled);
 			notifications->setText(enabled
 				? tr::lng_profile_action_short_mute(tr::now)
@@ -828,7 +829,7 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 				});
 		buttons.push_back(notifications);
 		_actions->add(notifications);
-		_edgeColor.value() | rpl::start_with_next([=](
+		_edgeColor.value() | rpl::on_next([=](
 				std::optional<QColor> c) {
 			notifications->setLottieColor(c
 				? (const style::color*)(nullptr)
@@ -1052,7 +1053,7 @@ void TopBar::setupUserpicButton(
 		_peer->session().downloaderTaskFinished(
 		) | rpl::filter([=] {
 			return !Ui::PeerUserpicLoading(_userpicView);
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			update();
 			_userpicLoadingLifetime.destroy();
 		}, _userpicLoadingLifetime);
@@ -1068,14 +1069,14 @@ void TopBar::setupUserpicButton(
 			_peer,
 			Data::PeerUpdate::Flag::Photo
 				| Data::PeerUpdate::Flag::FullInfo) | rpl::to_empty
-	) | rpl::start_with_next(invalidate, lifetime());
+	) | rpl::on_next(invalidate, lifetime());
 
 	if (const auto broadcast = _peer->monoforumBroadcast()) {
 		_peer->session().changes().peerFlagsValue(
 			broadcast,
 			Data::PeerUpdate::Flag::Photo
 				| Data::PeerUpdate::Flag::FullInfo
-		) | rpl::to_empty | rpl::start_with_next(invalidate, lifetime());
+		) | rpl::to_empty | rpl::on_next(invalidate, lifetime());
 	}
 
 	using ChosenType = Ui::UserpicButton::ChosenType;
@@ -1114,8 +1115,8 @@ void TopBar::setupUserpicButton(
 			.about = (*phrase)(
 				tr::now,
 				lt_user,
-				Ui::Text::Bold(name),
-				Ui::Text::WithEntities),
+				tr::bold(name),
+				tr::marked),
 			.confirm = ((type == ChosenType::Suggest)
 				? tr::lng_profile_suggest_button(tr::now)
 				: tr::lng_profile_set_photo_button(tr::now)),
@@ -1158,7 +1159,7 @@ void TopBar::setupUserpicButton(
 		}
 	};
 
-	_userpicButton->clicks() | rpl::start_with_next([=](
+	_userpicButton->clicks() | rpl::on_next([=](
 			Qt::MouseButton button) {
 		if (button == Qt::RightButton && hasMenu()) {
 			*menu = base::make_unique_q<Ui::PopupMenu>(
@@ -1261,8 +1262,8 @@ void TopBar::setupUserpicButton(
 						const auto text = tr::lng_profile_topic_toast(
 							tr::now,
 							lt_name,
-							Ui::Text::Link(packName, u"internal:"_q),
-							Ui::Text::WithEntities);
+							tr::link(packName, u"internal:"_q),
+							tr::marked);
 						const auto weak = base::make_weak(controller);
 						controller->showToast(Ui::Toast::Config{
 							.text = text,
@@ -1297,7 +1298,7 @@ void TopBar::setupUniqueBadgeTooltip() {
 	}
 	base::timer_once(kWaitBeforeGiftBadge) | rpl::then(
 		_badge->updated()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		const auto widget = _badge->widget();
 		const auto &content = _badgeContent.current();
 		const auto &collectible = content.emojiStatusId.collectible;
@@ -1339,7 +1340,7 @@ void TopBar::hideBadgeTooltip() {
 		raw->shownValue(
 		) | rpl::filter(
 			!rpl::mappers::_1
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			const auto i = ranges::find(
 				_badgeOldTooltips,
 				raw,
@@ -1361,7 +1362,7 @@ rpl::producer<> TopBar::backRequest() const {
 }
 
 void TopBar::setOnlineCount(rpl::producer<int> &&count) {
-	std::move(count) | rpl::start_with_next([=](int v) {
+	std::move(count) | rpl::on_next([=](int v) {
 		if (_statusLabel) {
 			_statusLabel->setOnlineCount(v);
 		}
@@ -1829,7 +1830,7 @@ void TopBar::setupButtons(
 	rpl::combine(
 		_wrap.value(),
 		_edgeColor.value()
-	) | rpl::start_with_next([=](
+	) | rpl::on_next([=](
 			Wrap wrap,
 			std::optional<QColor> edgeColor) mutable {
 		const auto isLayer = (wrap == Wrap::Layer);
@@ -1856,7 +1857,7 @@ void TopBar::setupButtons(
 		_back->QWidget::show();
 		_back->setDuration(0);
 		_back->toggleOn(isLayer || isSide
-			? (_backToggles.value() | rpl::type_erased())
+			? (_backToggles.value() | rpl::type_erased)
 			: rpl::single(wrap == Wrap::Narrow));
 		_back->entity()->clicks() | rpl::to_empty | rpl::start_to_stream(
 			_backClicks,
@@ -1877,7 +1878,7 @@ void TopBar::setupButtons(
 					controller->hideLayer();
 					controller->hideSpecialLayer();
 				}));
-			widthValue() | rpl::start_with_next([=] {
+			widthValue() | rpl::on_next([=] {
 				_close->moveToRight(0, 0);
 			}, _close->lifetime());
 		}
@@ -1908,7 +1909,7 @@ void TopBar::addTopBarEditButton(
 		controller->showSettings(::Settings::Information::Id());
 	});
 
-	widthValue() | rpl::start_with_next([=] {
+	widthValue() | rpl::on_next([=] {
 		if (_close) {
 			_topBarButton->moveToRight(_close->width(), 0);
 		} else {
@@ -2021,7 +2022,7 @@ void TopBar::setupShowLastSeen(
 			user,
 			Data::PeerUpdate::Flag::OnlineStatus),
 		Data::AmPremiumValue(&user->session())
-	) | rpl::start_with_next([=](auto, bool premium) {
+	) | rpl::on_next([=](auto, bool premium) {
 		const auto wasShown = !_showLastSeen->isHidden();
 		const auto hiddenByMe = user->lastseen().isHiddenByMe();
 		const auto shown = hiddenByMe
@@ -2038,7 +2039,7 @@ void TopBar::setupShowLastSeen(
 		Api::UserPrivacy::Key::LastSeen
 	) | rpl::filter([=](Api::UserPrivacy::Rule rule) {
 		return (rule.option == Api::UserPrivacy::Option::Everyone);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		if (user->lastseen().isHiddenByMe()) {
 			user->updateFullForced();
 		}
@@ -2264,7 +2265,7 @@ void TopBar::setupNewGifts(
 	} else if (!_lottiePlayer) {
 		_lottiePlayer = std::make_unique<Lottie::MultiPlayer>(
 			Lottie::Quality::Default);
-		_lottiePlayer->updates() | rpl::start_with_next([=] {
+		_lottiePlayer->updates() | rpl::on_next([=] {
 			update();
 		}, lifetime());
 	}
@@ -2316,7 +2317,7 @@ void TopBar::setupNewGifts(
 		rpl::empty_value()
 	) | rpl::then(
 		_peer->session().downloaderTaskFinished()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto allLoaded = true;
 		for (auto &entry : _pinnedToTopGifts) {
 			if (!entry.animation && !entry.lastFrame.isNull()) {
@@ -2527,7 +2528,7 @@ void TopBar::setupStoryOutline(const QRect &geometry) {
 			) | rpl::filter([=](const Data::PeerUpdate &update) {
 				return update.peer == _peer;
 			}) | rpl::to_empty)
-	) | rpl::start_with_next([=](
+	) | rpl::on_next([=](
 			std::optional<QColor> edgeColor,
 			rpl::empty_value) {
 		const auto geometry = QRectF(userpicGeometry());
@@ -2680,7 +2681,7 @@ void TopBar::setupStatusWithRating() {
 	_status->setAttribute(Qt::WA_TransparentForMouseEvents);
 	if (const auto rating = _starsRating.get()) {
 		_statusShift = rating->widthValue();
-		_statusShift.changes() | rpl::start_with_next([=] {
+		_statusShift.changes() | rpl::on_next([=] {
 			updateLabelsPosition();
 		}, _status->lifetime());
 		rating->raise();
