@@ -44,12 +44,12 @@ MusicProvider::MusicProvider(not_null<AbstractController*> controller)
 , _peer(controller->key().musicPeer())
 , _history(_peer->owner().history(_peer)) {
 	_controller->session().data().itemRemoved(
-	) | rpl::start_with_next([this](auto item) {
+	) | rpl::on_next([this](auto item) {
 		itemRemoved(item);
 	}, _lifetime);
 
 	style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		for (auto &layout : _layouts) {
 			layout.second.item->invalidateCache();
 		}
@@ -168,7 +168,7 @@ void MusicProvider::refreshViewer() {
  	auto ids = Data::SavedMusicList(_peer, aroundId, _idsLimit);
 	std::move(
 		ids
-	) | rpl::start_with_next([=](Data::SavedMusicSlice &&slice) {
+	) | rpl::on_next([=](Data::SavedMusicSlice &&slice) {
 		if (!slice.fullCount()) {
 			// Don't display anything while full count is unknown.
 			return;
