@@ -45,6 +45,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/wrap/slide_wrap.h"
 #include "ui/wrap/vertical_layout.h"
 #include "ui/vertical_list.h"
+#include "ui/ui_utility.h"
 #include "styles/style_credits.h"
 #include "styles/style_dialogs.h"
 #include "styles/style_info.h"
@@ -98,7 +99,7 @@ EditAlbumBox::EditAlbumBox(
 , _changes(Data::StoryAlbumUpdate{ .peer = peer, .albumId = albumId })
 , _reload(std::move(reload)) {
 	_content->selectedListValue(
-	) | rpl::start_with_next([=](const SelectedItems &selection) {
+	) | rpl::on_next([=](const SelectedItems &selection) {
 		const auto stories = &_window->session().data().stories();
 		auto ids = stories->albumKnownInArchive(peer->id, albumId);
 		auto now = _changes.current();
@@ -124,7 +125,7 @@ void EditAlbumBox::prepare() {
 	setStyle(st::collectionEditBox);
 
 	_content->desiredHeightValue(
-	) | rpl::start_with_next([=](int height) {
+	) | rpl::on_next([=](int height) {
 		setDimensions(st::boxWideWidth, height);
 	}, _content->lifetime());
 
@@ -216,7 +217,7 @@ InnerWidget::InnerWidget(
 	preloadArchiveCount();
 
 	_albumId.value(
-	) | rpl::start_with_next([=](int albumId) {
+	) | rpl::on_next([=](int albumId) {
 		if (_albumsTabs
 			&& (albumId == Data::kStoriesAlbumIdSaved
 				|| ranges::contains(
@@ -245,7 +246,7 @@ void InnerWidget::preloadArchiveCount() {
 		rpl::mappers::_1 == key
 	) | rpl::take_while([=] {
 		return !stories->albumIdsCountKnown(_peer->id, kArchive);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		refreshAlbumsTabs();
 	}, lifetime());
 }
@@ -256,7 +257,7 @@ void InnerWidget::setupAlbums() {
 
 	_peer->owner().stories().albumsListValue(
 		_peer->id
-	) | rpl::start_with_next([=](std::vector<Data::StoryAlbum> &&albums) {
+	) | rpl::on_next([=](std::vector<Data::StoryAlbum> &&albums) {
 		_albums = std::move(albums);
 		refreshAlbumsTabs();
 	}, lifetime());
@@ -429,7 +430,7 @@ void InnerWidget::addRecentButton(Ui::MultiSlideTracker &tracker) {
 	rpl::combine(
 		recent->sizeValue(),
 		rpl::duplicate(last)
-	) | rpl::start_with_next([=](QSize size, const Content &content) {
+	) | rpl::on_next([=](QSize size, const Content &content) {
 		if (content.elements.empty()) {
 			return;
 		}
@@ -553,7 +554,7 @@ void InnerWidget::finalizeTop() {
 	_top->resizeToWidth(width());
 
 	_top->heightValue(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		refreshHeight();
 	}, _top->lifetime());
 }
@@ -577,6 +578,7 @@ void InnerWidget::createAboutArchive() {
 void InnerWidget::visibleTopBottomUpdated(
 		int visibleTop,
 		int visibleBottom) {
+	_visibleRange = { visibleTop, visibleBottom };
 	setChildVisibleTopBottom(_list, visibleTop, visibleBottom);
 }
 
@@ -609,7 +611,8 @@ void InnerWidget::setupList() {
 					int newPosition,
 					Fn<void()> done,
 					Fn<void()> fail) {
-				reorderAlbumStories(
+				_peer->owner().stories().albumReorderStories(
+					_peer,
 					albumId,
 					oldPosition,
 					newPosition,
@@ -631,6 +634,10 @@ void InnerWidget::setupList() {
 	_listTops.fire(raw->topValue());
 
 	raw->show();
+
+	Ui::PostponeCall(crl::guard(this, [=] {
+		visibleTopBottomUpdated(_visibleRange.top, _visibleRange.bottom);
+	}));
 }
 
 void InnerWidget::setupEmpty() {
@@ -647,7 +654,7 @@ void InnerWidget::setupEmpty() {
 			) | rpl::to_empty
 		),
 		_list->heightValue()
-	) | rpl::start_with_next([=](auto, int listHeight) {
+	) | rpl::on_next([=](auto, int listHeight) {
 		const auto padding = st::infoMediaMargin;
 		if (const auto raw = _empty.release()) {
 			raw->hide();
@@ -711,10 +718,10 @@ void InnerWidget::refreshEmpty() {
 		_empty = object_ptr<Ui::FlatLabel>(
 			this,
 			(!knownEmpty
-				? tr::lng_contacts_loading(Ui::Text::WithEntities)
+				? tr::lng_contacts_loading(tr::marked)
 				: _peer->isSelf()
-				? tr::lng_stories_empty(Ui::Text::RichLangValue)
-				: tr::lng_stories_empty_channel(Ui::Text::RichLangValue)),
+				? tr::lng_stories_empty(tr::rich)
+				: tr::lng_stories_empty_channel(tr::rich)),
 			st::giftListAbout);
 		_empty->show();
 	}
@@ -743,7 +750,7 @@ void InnerWidget::refreshAlbumsTabs() {
 			.id = u"all"_q,
 			.text = tr::lng_stories_album_all(
 				tr::now,
-				Ui::Text::WithEntities),
+				tr::marked),
 		});
 		for (const auto &album : _albums) {
 			auto title = TextWithEntities();
@@ -786,13 +793,13 @@ void InnerWidget::refreshAlbumsTabs() {
 		_albumsWrap->resize(
 			_albumsWrap->width(),
 			padding.top() + _albumsTabs->height() + padding.top());
-		_albumsWrap->widthValue() | rpl::start_with_next([=](int width) {
+		_albumsWrap->widthValue() | rpl::on_next([=](int width) {
 			_albumsTabs->resizeToWidth(width);
 		}, _albumsTabs->lifetime());
 		_albumsTabs->move(0, padding.top());
 
 		_albumsTabs->activated(
-		) | rpl::start_with_next([=](const QString &id) {
+		) | rpl::on_next([=](const QString &id) {
 			if (id == u"add"_q) {
 				const auto added = [=](Data::StoryAlbum album) {
 					albumAdded(album);
@@ -809,7 +816,7 @@ void InnerWidget::refreshAlbumsTabs() {
 		}, _albumsTabs->lifetime());
 
 		_albumsTabs->contextMenuRequests(
-		) | rpl::start_with_next([=](const QString &id) {
+		) | rpl::on_next([=](const QString &id) {
 			if (id == u"add"_q || id == u"all"_q) {
 				return;
 			}
@@ -818,7 +825,7 @@ void InnerWidget::refreshAlbumsTabs() {
 
 		using ReorderUpdate = Ui::SubTabsReorderUpdate;
 		_albumsTabs->reorderUpdates(
-		) | rpl::start_with_next([=](const ReorderUpdate &update) {
+		) | rpl::on_next([=](const ReorderUpdate &update) {
 			if (update.state == ReorderUpdate::State::Applied) {
 				reorderAlbumsLocally(update);
 			}
@@ -1122,52 +1129,4 @@ void InnerWidget::flushAlbumReorder() {
 	_pendingAlbumReorder = false;
 }
 
-void InnerWidget::reorderAlbumStories(
-		int albumId,
-		int oldPosition,
-		int newPosition,
-		Fn<void()> done,
-		Fn<void()> fail) {
-	const auto &stories = _controller->session().data().stories();
-	const auto ids = stories.albumIds(_peer->id, albumId);
-	const auto list = Data::RespectingPinned(ids);
-
-	if (oldPosition < 0 || newPosition < 0
-		|| oldPosition >= list.size() || newPosition >= list.size()) {
-		fail();
-		return;
-	}
-
-	if (_reorderStoriesRequestId) {
-		_controller->session().api().request(
-			base::take(_reorderStoriesRequestId)).cancel();
-	}
-
-	auto reorderedList = list;
-	base::reorder(reorderedList, oldPosition, newPosition);
-
-	auto order = QVector<MTPint>();
-	order.reserve(reorderedList.size());
-	for (const auto id : reorderedList) {
-		order.push_back(MTP_int(id));
-	}
-
-	_reorderStoriesRequestId = _controller->session().api().request(
-		MTPstories_UpdateAlbum(
-			MTP_flags(MTPstories_UpdateAlbum::Flag::f_order),
-			_peer->input,
-			MTP_int(albumId),
-			MTPstring(),
-			MTPVector<MTPint>(),
-			MTPVector<MTPint>(),
-			MTP_vector<MTPint>(order)
-	)).done([=](const MTPStoryAlbum &result) {
-		_reorderStoriesRequestId = 0;
-		done();
-	}).fail([=] {
-		_reorderStoriesRequestId = 0;
-		fail();
-	}).send();
-}
-
 } // namespace Info::Stories
