@@ -157,10 +157,9 @@ constexpr auto kPopularAppBotsLimit = 100;
 				.requestWriteAccess = data.is_request_write_access(),
 			} : std::optional<AttachWebViewBot>();
 	});
-	if (result && result->icon) {
-		result->icon->forceToCache(true);
-	}
-	if (const auto icon = result->icon) {
+	if (const auto icon = result ? result->icon : nullptr) {
+		icon->forceToCache(true);
+
 		result->media = icon->createMediaView();
 		icon->save(Data::FileOrigin(), {});
 	}
@@ -287,7 +286,7 @@ void FillDisclaimerBox(
 	Ui::ConfirmBox(box, {
 		.text = tr::lng_mini_apps_disclaimer_text(
 			tr::now,
-			Ui::Text::RichLangValue),
+			tr::rich),
 		.confirmed = callback,
 		.cancelled = [=](Fn<void()> close) { done(false); close(); },
 		.confirmText = tr::lng_box_ok(),
@@ -305,10 +304,10 @@ void FillDisclaimerBox(
 			box.get(),
 			tr::lng_mini_apps_disclaimer_button(
 				lt_link,
-				rpl::single(Ui::Text::Link(
+				rpl::single(tr::link(
 					tr::lng_mini_apps_disclaimer_link(tr::now),
 					tr::lng_mini_apps_tos_url(tr::now))),
-				Ui::Text::WithEntities),
+				tr::marked),
 			st::urlAuthCheckbox,
 			std::move(checkView)),
 		{
@@ -388,9 +387,9 @@ void FillBotUsepic(
 		tr::lng_allow_bot_webview_details(
 			lt_emoji,
 			rpl::single(Ui::Text::IconEmoji(&st::textMoreIconEmoji)),
-			Ui::Text::RichLangValue
+			tr::rich
 		) | rpl::map([](TextWithEntities text) {
-			return Ui::Text::Link(std::move(text), u"internal:"_q);
+			return tr::link(std::move(text), u"internal:"_q);
 		}),
 		st::defaultFlatLabel);
 	const auto userpic = Ui::CreateChild<Ui::UserpicButton>(
@@ -420,12 +419,12 @@ void FillBotUsepic(
 		titleLabel->width() + (icon ? icon->width() : 0),
 		titleLabel->height());
 	title->widthValue(
-	) | rpl::distinct_until_changed() | rpl::start_with_next([=](int w) {
+	) | rpl::distinct_until_changed() | rpl::on_next([=](int w) {
 		titleLabel->resizeToWidth(w
 			- (icon ? icon->width() + st::lineWidth : 0));
 	}, title->lifetime());
 	if (icon) {
-		title->paintRequest() | rpl::start_with_next([=] {
+		title->paintRequest() | rpl::on_next([=] {
 			auto p = Painter(title);
 			p.fillRect(title->rect(), Qt::transparent);
 			const auto x = std::min(
@@ -510,7 +509,7 @@ void ConfirmEmojiStatusAccessBox(
 
 	AddSkip(box->verticalLayout(), 2 * st::defaultVerticalListSkip);
 
-	auto name = Ui::Text::Bold(bot->name());
+	auto name = tr::bold(bot->name());
 	box->addRow(
 		object_ptr<Ui::FlatLabel>(
 			box,
@@ -519,7 +518,7 @@ void ConfirmEmojiStatusAccessBox(
 				rpl::single(name),
 				lt_name,
 				rpl::single(name),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			st::botEmojiStatusText),
 		style::al_top);
 
@@ -572,8 +571,8 @@ void ConfirmEmojiStatusBox(
 			box,
 			tr::lng_bot_emoji_status_text(
 				lt_bot,
-				rpl::single(Ui::Text::Bold(bot->name())),
-				Ui::Text::RichLangValue),
+				rpl::single(tr::bold(bot->name())),
+				tr::rich),
 			st::botEmojiStatusText),
 		style::al_top);
 
@@ -600,7 +599,7 @@ void ConfirmEmojiStatusBox(
 	box->addButton(tr::lng_cancel(), [=] {
 		box->closeBox();
 	});
-	box->boxClosing() | rpl::start_with_next([=] {
+	box->boxClosing() | rpl::on_next([=] {
 		if (!*set) {
 			done(false);
 		}
@@ -672,7 +671,7 @@ BotAction::BotAction(
 	_icon.move(_st.itemIconPosition);
 
 	paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Painter p(this);
 		paint(p);
 	}, lifetime());
@@ -778,7 +777,7 @@ MenuBotIcon::MenuBotIcon(
 : RpWidget(parent)
 , _media(std::move(media)) {
 	style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_image = QImage();
 		update();
 	}, lifetime());
@@ -899,7 +898,7 @@ void WebViewInstance::requestFullBot() {
 	_bot->session().changes().peerUpdates(
 		_bot,
 		Data::PeerUpdate::Flag::FullInfo
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (_botFullWaitingArgs.has_value()) {
 			auto args = *base::take(_botFullWaitingArgs);
 			if (args.url.isEmpty()) {
@@ -1059,10 +1058,10 @@ void WebViewInstance::confirmOpen(Fn<void()> done) {
 			.text = tr::lng_profile_open_app_about(
 				tr::now,
 				lt_terms,
-				Ui::Text::Link(
+				tr::link(
 					tr::lng_profile_open_app_terms(tr::now),
 					tr::lng_mini_apps_tos_url(tr::now)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			.confirmed = crl::guard(this, callback),
 			.cancelled = crl::guard(this, cancel),
 			.confirmText = tr::lng_view_button_bot_app(),
@@ -1096,10 +1095,10 @@ void WebViewInstance::confirmAppOpen(
 			tr::lng_profile_open_app_about(
 				tr::now,
 				lt_terms,
-				Ui::Text::Link(
+				tr::link(
 					tr::lng_profile_open_app_terms(tr::now),
 					tr::lng_mini_apps_tos_url(tr::now)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			crl::guard(this, callback),
 			crl::guard(this, cancelled),
 			tr::lng_view_button_bot_app(),
@@ -1111,8 +1110,8 @@ void WebViewInstance::confirmAppOpen(
 					tr::lng_url_auth_allow_messages(
 						tr::now,
 						lt_bot,
-						Ui::Text::Bold(_bot->name()),
-						Ui::Text::WithEntities),
+						tr::bold(_bot->name()),
+						tr::marked),
 					true,
 					st::urlAuthCheckbox),
 				style::margins(
@@ -1346,7 +1345,7 @@ void WebViewInstance::show(ShowArgs &&args) {
 		: nullptr;
 	if (titleBadge) {
 		const auto raw = titleBadge.data();
-		raw->paintRequest() | rpl::start_with_next([=] {
+		raw->paintRequest() | rpl::on_next([=] {
 			auto p = Painter(raw);
 			const auto w = raw->width();
 			st::infoVerifiedStar.paint(p, st::lineWidth, 0, w);
@@ -1436,14 +1435,14 @@ void WebViewInstance::started(uint64 queryId) {
 	_session->data().webViewResultSent(
 	) | rpl::filter([=](const Data::Session::WebViewResultSent &sent) {
 		return (sent.queryId == queryId);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		close();
 	}, _panel->lifetime());
 
 	const auto action = *_context.action;
 	base::timer_each(
 		kProlongTimeout
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		using Flag = MTPmessages_ProlongWebView::Flag;
 		_session->api().request(base::take(_prolongId)).cancel();
 		_prolongId = _session->api().request(MTPmessages_ProlongWebView(
@@ -1625,8 +1624,8 @@ void WebViewInstance::botHandleMenuButton(
 				: tr::lng_bot_remove_from_menu_sure)(
 					tr::now,
 					lt_bot,
-					Ui::Text::Bold(name),
-					Ui::Text::WithEntities),
+					tr::bold(name),
+					tr::marked),
 			done,
 		}));
 	} break;
@@ -1960,7 +1959,7 @@ void WebViewInstance::botSendPreparedMessage(
 			};
 			state->send({});
 		});
-		box->boxClosing() | rpl::start_with_next([=] {
+		box->boxClosing() | rpl::on_next([=] {
 			if (!state->sent) {
 				callback("USER_DECLINED");
 			}
@@ -1984,7 +1983,7 @@ void WebViewInstance::botSetEmojiStatus(
 	}
 	_session->data().customEmojiManager().resolve(
 		request.customEmojiId
-	) | rpl::start_with_next_error([=](not_null<DocumentData*> document) {
+	) | rpl::on_next_error([=](not_null<DocumentData*> document) {
 		const auto sticker = document->sticker();
 		if (!sticker || sticker->setType != Data::StickersType::Emoji) {
 			callback(u"SUGGESTED_EMOJI_INVALID"_q);
@@ -2499,8 +2498,8 @@ void AttachWebView::confirmAddToMenu(
 				box,
 				tr::lng_bot_will_be_added(
 					lt_bot,
-					rpl::single(Ui::Text::Bold(bot.name)),
-					Ui::Text::WithEntities),
+					rpl::single(tr::bold(bot.name)),
+					tr::marked),
 				st::boxLabel));
 		} else {
 			Ui::ConfirmBox(box, {
@@ -2509,8 +2508,8 @@ void AttachWebView::confirmAddToMenu(
 					: tr::lng_bot_add_to_menu)(
 						tr::now,
 						lt_bot,
-						Ui::Text::Bold(bot.name),
-						Ui::Text::WithEntities),
+						tr::bold(bot.name),
+						tr::marked),
 				done,
 				(callback
 					? [=](Fn<void()> close) { callback(false); close(); }
@@ -2523,8 +2522,8 @@ void AttachWebView::confirmAddToMenu(
 						tr::lng_url_auth_allow_messages(
 							tr::now,
 							lt_bot,
-							Ui::Text::Bold(bot.name),
-							Ui::Text::WithEntities),
+							tr::bold(bot.name),
+							tr::marked),
 						true,
 						st::urlAuthCheckbox),
 					style::margins(
@@ -2727,7 +2726,7 @@ std::unique_ptr<Ui::DropdownMenu> MakeAttachBotsMenu(
 			bot,
 			callback);
 		action->forceShown(
-		) | rpl::start_with_next([=](bool shown) {
+		) | rpl::on_next([=](bool shown) {
 			if (shown) {
 				raw->setAutoHiding(false);
 			} else {
