@@ -65,25 +65,25 @@ PhoneWidget::PhoneWidget(
 	_code->setAccessibleName(tr::lng_country_code(tr::now));
 	_phone->setAccessibleName(tr::lng_phone_number(tr::now));
 	_phone->frontBackspaceEvent(
-	) | rpl::start_with_next([=](not_null<QKeyEvent*> e) {
+	) | rpl::on_next([=](not_null<QKeyEvent*> e) {
 		_code->startErasing(e);
 	}, _code->lifetime());
 
 	_country->codeChanged(
-	) | rpl::start_with_next([=](const QString &code) {
+	) | rpl::on_next([=](const QString &code) {
 		_code->codeSelected(code);
 		_phone->chooseCode(code);
 	}, _country->lifetime());
 	_code->codeChanged(
-	) | rpl::start_with_next([=](const QString &code) {
+	) | rpl::on_next([=](const QString &code) {
 		_country->onChooseCode(code);
 		_phone->chooseCode(code);
 	}, _code->lifetime());
 	_code->addedToNumber(
-	) | rpl::start_with_next([=](const QString &added) {
+	) | rpl::on_next([=](const QString &added) {
 		_phone->addedToNumber(added);
 	}, _phone->lifetime());
-	_code->spacePressed() | rpl::start_with_next([=] {
+	_code->spacePressed() | rpl::on_next([=] {
 		submit();
 	}, _code->lifetime());
 	connect(_phone, &Ui::PhonePartInput::changed, [=] { phoneChanged(); });
@@ -92,7 +92,7 @@ PhoneWidget::PhoneWidget(
 	setTitleText(tr::lng_phone_title());
 	setDescriptionText(tr::lng_phone_desc());
 	getData()->updated.events(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		countryChanged();
 	}, lifetime());
 	setErrorCentered(true);
@@ -119,7 +119,7 @@ void PhoneWidget::setupQrLogin() {
 	rpl::combine(
 		sizeValue(),
 		qrLogin->widthValue()
-	) | rpl::start_with_next([=](QSize size, int qrLoginWidth) {
+	) | rpl::on_next([=](QSize size, int qrLoginWidth) {
 		qrLogin->moveToLeft(
 			(size.width() - qrLoginWidth) / 2,
 			contentTop() + st::introQrLoginLinkTop);
