@@ -107,7 +107,7 @@ constexpr auto kLoadViewsPages = 2;
 			list.front()->session().downloaderTaskFinished(
 			) | rpl::filter([=] {
 				return state->someUserpicsNotLoaded && !state->scheduled;
-			}) | rpl::start_with_next([=] {
+			}) | rpl::on_next([=] {
 				for (const auto &userpic : state->userpics) {
 					if (userpic.peer->userpicUniqueKey(userpic.view)
 						!= userpic.uniqueKey) {
@@ -137,8 +137,12 @@ constexpr auto kLoadViewsPages = 2;
 
 } // namespace
 
-RecentViewsType RecentViewsTypeFor(not_null<PeerData*> peer) {
-	return peer->isSelf()
+RecentViewsType RecentViewsTypeFor(
+		not_null<PeerData*> peer,
+		bool videoStream) {
+	return videoStream
+		? RecentViewsType::Other
+		: peer->isSelf()
 		? RecentViewsType::Self
 		: peer->isBroadcast()
 		? RecentViewsType::Channel
@@ -169,7 +173,7 @@ void RecentViews::show(
 				likedValue
 			) | rpl::map([](const Data::ReactionId &id) {
 				return !id.empty();
-			}) | rpl::start_with_next([=](bool liked) {
+			}) | rpl::on_next([=](bool liked) {
 				const auto icon = liked
 					? &st::storiesComposeControls.liked
 					: &st::storiesLikesIcon;
@@ -255,7 +259,7 @@ void RecentViews::refreshClickHandler() {
 				&& (e->type() == QEvent::MouseButtonPress)
 				&& (static_cast<QMouseEvent*>(e.get())->button()
 					== Qt::LeftButton);
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			showMenu();
 		});
 	}
@@ -267,7 +271,7 @@ void RecentViews::refreshClickHandler() {
 void RecentViews::updateUserpics() {
 	_userpicsLifetime = ContentByUsers(
 		_data.list
-	) | rpl::start_with_next([=](
+	) | rpl::on_next([=](
 			const std::vector<Ui::GroupCallUser> &list) {
 		_userpics->update(list, true);
 	});
@@ -280,7 +284,7 @@ void RecentViews::setupUserpics() {
 		rpl::single(true),
 		[=] { _widget->update(); });
 
-	_userpics->widthValue() | rpl::start_with_next([=](int width) {
+	_userpics->widthValue() | rpl::on_next([=](int width) {
 		if (_userpicsWidth != width) {
 			_userpicsWidth = width;
 			updatePartsGeometry();
@@ -294,13 +298,13 @@ void RecentViews::setupWidget() {
 	raw->show();
 
 	_controller->layoutValue(
-	) | rpl::start_with_next([=](const Layout &layout) {
+	) | rpl::on_next([=](const Layout &layout) {
 		_outer = layout.views;
 		updatePartsGeometry();
 	}, raw->lifetime());
 
 	raw->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = Painter(raw);
 		_userpics->paint(
 			p,
@@ -325,7 +329,7 @@ void RecentViews::setupViewsReactions() {
 	_likeIcon->setAttribute(Qt::WA_TransparentForMouseEvents);
 
 	_controller->layoutValue(
-	) | rpl::start_with_next([=](const Layout &layout) {
+	) | rpl::on_next([=](const Layout &layout) {
 		_outer = QRect(
 			layout.content.x(),
 			layout.views.y(),
@@ -342,7 +346,7 @@ void RecentViews::setupViewsReactions() {
 	views->setAttribute(Qt::WA_TransparentForMouseEvents);
 
 	views->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		const auto left = (_data.type == RecentViewsType::Changelog)
 			? st::mediaviewCaptionPadding.left()
 			: st::storiesViewsTextPosition.x();
@@ -352,7 +356,7 @@ void RecentViews::setupViewsReactions() {
 	}, _viewsWrap->lifetime());
 	_viewsWrap->paintRequest() | rpl::filter([=] {
 		return (_data.type != RecentViewsType::Changelog);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		auto p = QPainter(_viewsWrap.get());
 		const auto &icon = st::storiesViewsIcon;
 		const auto top = (_viewsWrap->height() - icon.height()) / 2;
@@ -369,7 +373,7 @@ void RecentViews::setupViewsReactions() {
 	likes->move(st::storiesLikesTextPosition);
 
 	likes->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		width += width
 			? st::storiesLikesTextRightSkip
 			: st::storiesLikesEmptyRightSkip;
@@ -476,7 +480,7 @@ void RecentViews::showMenu() {
 				< (scrollTop
 					+ st::storiesViewsMenu.maxHeight * kLoadViewsPages);
 		}) | rpl::to_empty
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		rebuildMenuTail();
 	}, _menuShortLifetime);
 
@@ -626,7 +630,7 @@ void RecentViews::subscribeToMenuUserpicsLoading(
 			}
 			return true;
 		})
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_waitingUserpicsCheck = false;
 		for (auto i = begin(_waitingForUserpics)
 			; i != end(_waitingForUserpics)
