@@ -363,24 +363,24 @@ void PipPanel::init() {
 		return widget()->windowHandle()
 			&& widget()->windowHandle()->isExposed();
 	}) | rpl::distinct_until_changed(
-	) | rpl::filter(rpl::mappers::_1) | rpl::start_with_next([=] {
+	) | rpl::filter(rpl::mappers::_1) | rpl::on_next([=] {
 		// Workaround Qt's forced transient parent.
 		Ui::Platform::ClearTransientParent(widget());
 	}, rp()->lifetime());
 
 	rp()->shownValue(
-	) | rpl::filter(rpl::mappers::_1) | rpl::start_with_next([=] {
+	) | rpl::filter(rpl::mappers::_1) | rpl::on_next([=] {
 		Ui::Platform::SetWindowMargins(widget(), _padding);
 	}, rp()->lifetime());
 
 	rp()->screenValue(
-	) | rpl::skip(1) | rpl::start_with_next([=](not_null<QScreen*> screen) {
+	) | rpl::skip(1) | rpl::on_next([=](not_null<QScreen*> screen) {
 		handleScreenChanged(screen);
 	}, rp()->lifetime());
 
 	if (Platform::IsWayland()) {
 		rp()->sizeValue(
-		) | rpl::skip(1) | rpl::start_with_next([=](QSize size) {
+		) | rpl::skip(1) | rpl::on_next([=](QSize size) {
 			handleWaylandResize(size);
 		}, rp()->lifetime());
 	}
@@ -932,13 +932,13 @@ Pip::Pip(
 	setupStreaming();
 
 	_data->session().account().sessionChanges(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_destroy();
 	}, _panel.rp()->lifetime());
 
 	if (_context) {
 		_data->owner().itemRemoved(
-		) | rpl::start_with_next([=](not_null<const HistoryItem*> data) {
+		) | rpl::on_next([=](not_null<const HistoryItem*> data) {
 			if (_context != data) {
 				_context = nullptr;
 			}
@@ -971,12 +971,12 @@ void Pip::setupPanel() {
 	_panel.widget()->show();
 
 	_panel.saveGeometryRequests(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		saveGeometry();
 	}, _panel.rp()->lifetime());
 
 	_panel.rp()->events(
-	) | rpl::start_with_next([=](not_null<QEvent*> e) {
+	) | rpl::on_next([=](not_null<QEvent*> e) {
 		const auto mousePosition = [&] {
 			return static_cast<QMouseEvent*>(e.get())->pos();
 		};
@@ -1234,7 +1234,7 @@ void Pip::setupButtons() {
 	_panel.rp()->sizeValue(
 	) | rpl::map([=] {
 		return _panel.inner();
-	}) | rpl::start_with_next([=](QRect rect) {
+	}) | rpl::on_next([=](QRect rect) {
 		const auto skip = st::pipControlSkip;
 		_close.area = QRect(
 			rect.x(),
@@ -1338,7 +1338,7 @@ void Pip::setupStreaming() {
 	_instance->switchQualityRequests(
 	) | rpl::filter([=](int quality) {
 		return !_quality.manual && _quality.height != quality;
-	}) | rpl::start_with_next([=](int quality) {
+	}) | rpl::on_next([=](int quality) {
 		applyVideoQuality({
 			.manual = 0,
 			.height = uint32(quality),
@@ -1346,7 +1346,7 @@ void Pip::setupStreaming() {
 	}, _instance->lifetime());
 
 	_instance->player().updates(
-	) | rpl::start_with_next_error([=](Streaming::Update &&update) {
+	) | rpl::on_next_error([=](Streaming::Update &&update) {
 		handleStreamingUpdate(std::move(update));
 	}, [=](Streaming::Error &&error) {
 		handleStreamingError(std::move(error));
