@@ -77,7 +77,7 @@ void AboutBox(
 		owned->setNaturalWidth(rect.width());
 		const auto widget = box->addRow(std::move(owned), style::al_top);
 		widget->paintRequest(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			auto p = Painter(widget);
 			auto hq = PainterHighQualityEnabler(p);
 			p.setPen(Qt::NoPen);
@@ -129,13 +129,13 @@ void AboutBox(
 			const auto left = Ui::CreateChild<Ui::RpWidget>(
 				box->verticalLayout().get());
 			left->paintRequest(
-			) | rpl::start_with_next([=] {
+			) | rpl::on_next([=] {
 				auto p = Painter(left);
 				icon.paint(p, 0, 0, left->width());
 			}, left->lifetime());
 			left->resize(icon.size());
 			top->geometryValue(
-			) | rpl::start_with_next([=](const QRect &g) {
+			) | rpl::on_next([=](const QRect &g) {
 				left->moveToLeft(
 					(g.left() - left->width()) / 2,
 					g.top() + st::channelEarnHistoryThreeSkip);
@@ -149,7 +149,7 @@ void AboutBox(
 				: isSearch
 				? tr::lng_sponsored_revenued_info1_search_description
 				: tr::lng_sponsored_revenued_info1_bot_description)(
-					Ui::Text::RichLangValue),
+					tr::rich),
 			st::sponsoredAboutPrivacyIcon);
 		if (!isSearch) {
 			Ui::AddSkip(content);
@@ -161,14 +161,14 @@ void AboutBox(
 				(isChannel
 					? tr::lng_sponsored_revenued_info2_description
 					: tr::lng_sponsored_revenued_info2_bot_description)(
-						Ui::Text::RichLangValue),
+						tr::rich),
 				st::sponsoredAboutSplitIcon);
 		}
 		Ui::AddSkip(content);
 		Ui::AddSkip(content);
 		auto link = tr::lng_settings_privacy_premium_link(
 		) | rpl::map([](QString t) {
-			return Ui::Text::Link(std::move(t), u"internal:"_q);
+			return tr::link(std::move(t), u"internal:"_q);
 		});
 		addEntry(
 			tr::lng_sponsored_revenued_info3_title(),
@@ -178,7 +178,7 @@ void AboutBox(
 					rpl::single(float64(levels)),
 					lt_link,
 					std::move(link),
-					Ui::Text::RichLangValue)
+					tr::rich)
 				: isSearch
 				? tr::lng_sponsored_revenued_info3_search_description(
 					lt_link,
@@ -186,18 +186,18 @@ void AboutBox(
 						lt_arrow,
 						rpl::single(
 							Ui::Text::IconEmoji(&st::textMoreIconEmoji)),
-						Ui::Text::WithEntities
+						tr::marked
 					) | rpl::map([](TextWithEntities &&link) {
 						return Ui::Text::Wrapped(
 							std::move(link),
 							EntityType::CustomUrl,
 							u"internal:"_q);
 					}),
-					Ui::Text::RichLangValue)
+					tr::rich)
 				: tr::lng_sponsored_revenued_info3_bot_description(
 					lt_link,
 					std::move(link),
-					Ui::Text::RichLangValue)),
+					tr::rich)),
 			st::sponsoredAboutRemoveIcon)->setClickHandlerFilter([=](
 					const auto &...) {
 				ShowPremiumPreviewBox(show, PremiumFeature::NoAds);
@@ -233,11 +233,11 @@ void AboutBox(
 						tr::lng_channel_earn_about_link(
 							lt_emoji,
 							rpl::single(arrow),
-							Ui::Text::RichLangValue
+							tr::rich
 						) | rpl::map([=](TextWithEntities t) {
-							return Ui::Text::Link(std::move(t), kUrl.utf16());
+							return tr::link(std::move(t), kUrl.utf16());
 						}),
-						Ui::Text::RichLangValue),
+						tr::rich),
 				st::channelEarnLearnDescription))->resizeToWidth(available);
 	}
 	Ui::AddSkip(content);
@@ -261,7 +261,7 @@ void AboutBox(
 			box,
 			st::infoTopBarMenu);
 		box->widthValue(
-		) | rpl::start_with_next([=](int width) {
+		) | rpl::on_next([=](int width) {
 			top->raise();
 			top->moveToLeft(
 				width - top->width() - st::defaultScrollArea.width,
@@ -275,7 +275,7 @@ void AboutBox(
 				st::popupMenuWithIcons);
 			const auto raw = menu->get();
 			raw->animatePhaseValue(
-			) | rpl::start_with_next([=](Ui::PopupMenu::AnimatePhase phase) {
+			) | rpl::on_next([=](Ui::PopupMenu::AnimatePhase phase) {
 				top->setForceRippled(false
 					|| phase == Ui::PopupMenu::AnimatePhase::Shown
 					|| phase == Ui::PopupMenu::AnimatePhase::StartShow);
@@ -305,7 +305,7 @@ void AboutBox(
 void ShowReportSponsoredBox(
 		std::shared_ptr<ChatHelpers::Show> show,
 		Data::SponsoredReportAction report) {
-	const auto guideLink = Ui::Text::Link(
+	const auto guideLink = tr::link(
 		tr::lng_report_sponsored_reported_link(tr::now),
 		u"https://promote.telegram.org/guidelines"_q);
 
@@ -343,7 +343,7 @@ void ShowReportSponsoredBox(
 								tr::lng_report_sponsored_reported_learn(
 									lt_link,
 									rpl::single(guideLink),
-									Ui::Text::WithEntities),
+									tr::marked),
 								st::boxDividerLabel),
 							st::defaultBoxDividerLabelPadding));
 					}
@@ -364,7 +364,7 @@ void ShowReportSponsoredBox(
 						tr::now,
 						lt_link,
 						guideLink,
-						Ui::Text::WithEntities);
+						tr::marked);
 					show->showToast({
 						.text = std::move(text),
 						.duration = kToastDuration,
@@ -416,7 +416,7 @@ void FillSponsored(
 					st::historyHasCustomEmojiPosition,
 					base::duplicate(i));
 				item->clicks(
-				) | rpl::start_with_next(callback, menu->lifetime());
+				) | rpl::on_next(callback, menu->lifetime());
 				menu->addAction(std::move(item));
 				if (i != details.info.back()) {
 					menu->addSeparator();
