@@ -16,7 +16,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/wrap/slide_wrap.h"
 #include "ui/wrap/vertical_layout.h"
 #include "ui/chat/attach/attach_prepare.h"
-#include "ui/text/text_utilities.h" // Ui::Text::ToUpper
 #include "ui/text/text_options.h"
 #include "ui/image/image_prepare.h"
 #include "ui/painter.h"
@@ -225,7 +224,7 @@ Ui::SlideWrap<ScanButton> *EditScans::List::nonDeletedErrorRow() const {
 rpl::producer<QString> EditScans::List::uploadButtonText() const {
 	return (files.empty()
 		? tr::lng_passport_upload_scans
-		: tr::lng_passport_upload_more)() | Ui::Text::ToUpper();
+		: tr::lng_passport_upload_more)(tr::upper);
 }
 
 void EditScans::List::hideError() {
@@ -291,12 +290,12 @@ void EditScans::List::pushScan(const ScanInfo &info) {
 	const auto scan = rows.back()->entity();
 
 	scan->deleteClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		controller->deleteScan(type, index);
 	}, scan->lifetime());
 
 	scan->restoreClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		controller->restoreScan(type, index);
 	}, scan->lifetime());
 
@@ -684,9 +683,8 @@ void EditScans::setupSpecialScans(
 		}
 		auto label = scan.rowCreated.value(
 		) | rpl::map([=, type = type](bool created) {
-			return uploadText(type, created)();
-		}) | rpl::flatten_latest(
-		) | Ui::Text::ToUpper();
+			return uploadText(type, created)(tr::upper);
+		}) | rpl::flatten_latest();
 		scan.upload = inner->add(
 			object_ptr<Ui::SettingsButton>(
 				inner,
@@ -713,17 +711,17 @@ void EditScans::setupSpecialScans(
 
 void EditScans::init() {
 	_controller->scanUpdated(
-	) | rpl::start_with_next([=](ScanInfo &&info) {
+	) | rpl::on_next([=](ScanInfo &&info) {
 		updateScan(std::move(info));
 	}, lifetime());
 
 	widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		_content->resizeToWidth(width);
 	}, _content->lifetime());
 
 	_content->heightValue(
-	) | rpl::start_with_next([=](int height) {
+	) | rpl::on_next([=](int height) {
 		resize(width(), height);
 	}, _content->lifetime());
 }
@@ -822,12 +820,12 @@ void EditScans::createSpecialScanRow(
 	const auto row = scan.row->entity();
 
 	row->deleteClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_controller->deleteScan(type, std::nullopt);
 	}, row->lifetime());
 
 	row->restoreClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_controller->restoreScan(type, std::nullopt);
 	}, row->lifetime());
 
