@@ -8,6 +8,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "platform/mac/notifications_manager_mac.h"
 
 #include "base/platform/base_platform_info.h"
+#include "base/options.h"
 #include "base/platform/mac/base_utilities_mac.h"
 #include "base/random.h"
 #include "base/unixtime.h"
@@ -328,7 +329,7 @@ Manager::Private::Private(Manager *manager)
 , _delegate([[NotificationDelegate alloc] initWithManager:manager managerId:_managerId])
 , _sounds(ResolveSoundsFolder()) {
 	Core::App().settings().workModeValue(
-	) | rpl::start_with_next([=](Core::Settings::WorkMode mode) {
+	) | rpl::on_next([=](Core::Settings::WorkMode mode) {
 		// We need to update the delegate _after_ the tray icon change was done in Qt.
 		// Because Qt resets the delegate.
 		crl::on_main(this, [=] {
