@@ -91,14 +91,14 @@ void AddButtonIcon(
 	icon->widget.resize(icon->icon.size());
 	icon->widget.show();
 	button->sizeValue(
-	) | rpl::start_with_next([=, left = st.iconLeft](QSize size) {
+	) | rpl::on_next([=, left = st.iconLeft](QSize size) {
 		icon->widget.moveToLeft(
 			left,
 			(size.height() - icon->widget.height()) / 2,
 			size.width());
 	}, icon->widget.lifetime());
 	icon->widget.paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(&icon->widget);
 		icon->icon.paint(p, 0, 0);
 	}, icon->widget.lifetime());
@@ -145,7 +145,7 @@ void CreateRightLabel(
 			button->widthValue(),
 			std::move(buttonText),
 			v::text::take_plain(std::move(label))
-		) | rpl::start_with_next([=, &st](
+		) | rpl::on_next([=, &st](
 				int width,
 				const QString &button,
 				const QString &text) {
@@ -163,7 +163,7 @@ void CreateRightLabel(
 			button->widthValue(),
 			std::move(buttonText),
 			v::text::take_marked(std::move(label))
-		) | rpl::start_with_next([=, &st](
+		) | rpl::on_next([=, &st](
 				int width,
 				const QString &button,
 				const TextWithEntities &text) {
@@ -219,7 +219,7 @@ void AddDividerTextWithLottie(
 			anim::repeat::once);
 		std::move(
 			descriptor.showFinished
-		) | rpl::start_with_next([animate = std::move(icon.animate), repeat] {
+		) | rpl::on_next([animate = std::move(icon.animate), repeat] {
 			animate(repeat);
 		}, verticalLayout->lifetime());
 	}
@@ -237,7 +237,7 @@ void AddDividerTextWithLottie(
 	}
 
 	verticalLayout->geometryValue(
-	) | rpl::start_with_next([=](const QRect &r) {
+	) | rpl::on_next([=](const QRect &r) {
 		divider->setGeometry(r);
 	}, divider->lifetime());
 }
@@ -275,7 +275,7 @@ LottieIcon CreateLottieIcon(
 		start();
 	};
 	raw->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(raw);
 		const auto left = (raw->width() - width) / 2;
 		icon->paint(p, left, padding.top(), colorOverride
@@ -311,7 +311,7 @@ SliderWithLabel MakeSliderWithLabel(
 	rpl::combine(
 		raw->sizeValue(),
 		label->sizeValue()
-	) | rpl::start_with_next([=](QSize outer, QSize size) {
+	) | rpl::on_next([=](QSize outer, QSize size) {
 		const auto right = std::max(size.width(), minLabelWidth) + skip;
 		label->moveToRight(0, (outer.height() - size.height()) / 2);
 		const auto width = std::max(
