@@ -101,7 +101,7 @@ void LocalPasscodeEnter::setupContent() {
 
 	base::SystemUnlockStatus(
 		true
-	) | rpl::start_with_next([=](base::SystemUnlockAvailability status) {
+	) | rpl::on_next([=](base::SystemUnlockAvailability status) {
 		_systemUnlockWithBiometric = status.available
 			&& status.withBiometrics;
 	}, lifetime());
@@ -119,7 +119,7 @@ void LocalPasscodeEnter::setupContent() {
 		st::settingLocalPasscodeIconPadding);
 	content->add(std::move(icon.widget));
 	_showFinished.events(
-	) | rpl::start_with_next([animate = std::move(icon.animate)] {
+	) | rpl::on_next([animate = std::move(icon.animate)] {
 		animate(anim::repeat::once);
 	}, content->lifetime());
 
@@ -169,7 +169,7 @@ void LocalPasscodeEnter::setupContent() {
 			std::move(text));
 
 		container->geometryValue(
-		) | rpl::start_with_next([=](const QRect &r) {
+		) | rpl::on_next([=](const QRect &r) {
 			field->moveToLeft((r.width() - field->width()) / 2, 0);
 		}, container->lifetime());
 
@@ -293,7 +293,7 @@ void LocalPasscodeEnter::setupContent() {
 	}
 
 	_setInnerFocus.events(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (newPasscode->text().isEmpty()) {
 			newPasscode->setFocus();
 		} else if (reenterPasscode && reenterPasscode->text().isEmpty()) {
@@ -510,11 +510,11 @@ void LocalPasscodeManage::setupContent() {
 				st::boxDividerLabel),
 		st::defaultBoxDividerLabelPadding));
 	about->geometryValue(
-	) | rpl::start_with_next([=](const QRect &r) {
+	) | rpl::on_next([=](const QRect &r) {
 		divider->setGeometry(r);
 	}, divider->lifetime());
 	_isBottomFillerShown.value(
-	) | rpl::start_with_next([=](bool shown) {
+	) | rpl::on_next([=](bool shown) {
 		divider->skipEdge(Qt::BottomEdge, shown);
 	}, divider->lifetime());
 
@@ -546,7 +546,7 @@ void LocalPasscodeManage::setupContent() {
 	}));
 
 	unlockType->value(
-	) | rpl::start_with_next([=](UnlockType type) {
+	) | rpl::on_next([=](UnlockType type) {
 		while (systemUnlockContent->count()) {
 			delete systemUnlockContent->widgetAt(0);
 		}
@@ -575,7 +575,7 @@ void LocalPasscodeManage::setupContent() {
 		)->toggledChanges(
 		) | rpl::filter([=](bool value) {
 			return value != Core::App().settings().systemUnlockEnabled();
-		}) | rpl::start_with_next([=](bool value) {
+		}) | rpl::on_next([=](bool value) {
 			Core::App().settings().setSystemUnlockEnabled(value);
 			Core::App().saveSettingsDelayed();
 		}, systemUnlockContent->lifetime());
