@@ -193,7 +193,7 @@ Cover::Cover(
 			_badge.widget(),
 			_badge.sizeTag());
 	});
-	_badge.updated() | rpl::start_with_next([=] {
+	_badge.updated() | rpl::on_next([=] {
 		refreshNameGeometry(width());
 	}, _name->lifetime());
 }
@@ -203,7 +203,7 @@ Cover::~Cover() = default;
 void Cover::setupChildGeometry() {
 	using namespace rpl::mappers;
 	widthValue(
-	) | rpl::start_with_next([=](int newWidth) {
+	) | rpl::on_next([=](int newWidth) {
 		_userpic->moveToLeft(
 			st::settingsPhotoLeft,
 			st::settingsPhotoTop,
@@ -217,22 +217,22 @@ void Cover::setupChildGeometry() {
 void Cover::initViewers() {
 	Info::Profile::NameValue(
 		_user
-	) | rpl::start_with_next([=](const QString &name) {
+	) | rpl::on_next([=](const QString &name) {
 		_name->setText(name);
 		refreshNameGeometry(width());
 	}, lifetime());
 
 	Info::Profile::PhoneValue(
 		_user
-	) | rpl::start_with_next([=](const TextWithEntities &value) {
+	) | rpl::on_next([=](const TextWithEntities &value) {
 		_phone->setText(value.text);
 		refreshPhoneGeometry(width());
 	}, lifetime());
 
 	Info::Profile::UsernameValue(
 		_user
-	) | rpl::start_with_next([=](const TextWithEntities &value) {
-		_username->setMarkedText(Ui::Text::Link(value.text.isEmpty()
+	) | rpl::on_next([=](const TextWithEntities &value) {
+		_username->setMarkedText(tr::link(value.text.isEmpty()
 			? tr::lng_settings_username_add(tr::now)
 			: value.text));
 		refreshUsernameGeometry(width());
@@ -309,12 +309,12 @@ void Cover::refreshUsernameGeometry(int newWidth) {
 
 	const auto isPausedValue
 		= button->lifetime().make_state<rpl::variable<bool>>(isPaused());
-	isPausedValue->value() | rpl::start_with_next([=](bool value) {
+	isPausedValue->value() | rpl::on_next([=](bool value) {
 		ministars->setPaused(value);
 	}, ministarsContainer->lifetime());
 
 	ministarsContainer->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		(*isPausedValue) = isPaused();
 		auto p = QPainter(ministarsContainer);
 		{
@@ -346,13 +346,13 @@ void Cover::refreshUsernameGeometry(int newWidth) {
 	}();
 	badge->resize(star.size() / style::DevicePixelRatio());
 	badge->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(badge);
 		p.drawImage(0, 0, star);
 	}, badge->lifetime());
 
 	button->sizeValue(
-	) | rpl::start_with_next([=](const QSize &s) {
+	) | rpl::on_next([=](const QSize &s) {
 		badge->moveToLeft(
 			button->st().iconLeft
 				+ (st::menuIconShop.width() - badge->width()) / 2,
@@ -437,11 +437,10 @@ void SetupValidatePhoneNumberSuggestion(
 			content,
 			tr::lng_settings_suggestion_phone_number_about(
 				lt_link,
-				tr::lng_collectible_learn_more(
-				) | Ui::Text::ToLink(
+				tr::lng_collectible_learn_more(tr::url(
 					tr::lng_settings_suggestion_phone_number_about_link(
-						tr::now)),
-				Ui::Text::WithEntities),
+						tr::now))),
+				tr::marked),
 			st::boxLabel),
 		st::boxRowPadding);
 	label->setClickHandlerFilter([=, weak = base::make_weak(controller)](
@@ -502,7 +501,7 @@ void SetupValidatePhoneNumberSuggestion(
 					tr::lng_settings_suggestion_phone_number_change(
 						lt_emoji,
 						rpl::single(Ui::Text::SingleCustomEmoji(u"@"_q)),
-						Ui::Text::WithEntities),
+						tr::marked),
 					st::boxLabel,
 					st::defaultPopupMenu,
 					Ui::Text::MarkedContext{
@@ -512,7 +511,7 @@ void SetupValidatePhoneNumberSuggestion(
 		}));
 	});
 
-	wrap->widthValue() | rpl::start_with_next([=](int width) {
+	wrap->widthValue() | rpl::on_next([=](int width) {
 		const auto buttonWidth = (width - st::inviteLinkButtonsSkip) / 2;
 		yes->setFullWidth(buttonWidth);
 		no->setFullWidth(buttonWidth);
@@ -583,7 +582,7 @@ void SetupValidatePasswordSuggestion(
 		showOther(Settings::CloudPasswordSuggestionInputId());
 	});
 
-	wrap->widthValue() | rpl::start_with_next([=](int width) {
+	wrap->widthValue() | rpl::on_next([=](int width) {
 		const auto buttonWidth = (width - st::inviteLinkButtonsSkip) / 2;
 		yes->setFullWidth(buttonWidth);
 		no->setFullWidth(buttonWidth);
@@ -952,7 +951,7 @@ void SetupInterfaceScale(
 	button->toggledValue(
 	) | rpl::map([](bool checked) {
 		return checked ? style::kScaleAuto : cEvalScale(cConfigScale());
-	}) | rpl::start_with_next([=](int scale) {
+	}) | rpl::on_next([=](int scale) {
 		setScale(scale, setScale);
 	}, button->lifetime());
 
