@@ -13,6 +13,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "api/api_sensitive_content.h"
 #include "api/api_global_privacy.h"
 #include "api/api_websites.h"
+#include "data/components/passkeys.h"
+#include "platform/platform_webauthn.h"
 #include "settings/cloud_password/settings_cloud_password_email_confirm.h"
 #include "settings/cloud_password/settings_cloud_password_input.h"
 #include "settings/cloud_password/settings_cloud_password_login_email.h"
@@ -21,6 +23,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "settings/settings_blocked_peers.h"
 #include "settings/settings_global_ttl.h"
 #include "settings/settings_local_passcode.h"
+#include "settings/settings_passkeys.h"
 #include "settings/settings_premium.h" // Settings::ShowPremium.
 #include "settings/settings_privacy_controllers.h"
 #include "settings/settings_websites.h"
@@ -104,7 +107,7 @@ void AddPremiumStar(
 	auto star = PremiumStar();
 	badge->resize(star.size() / style::DevicePixelRatio());
 	badge->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(badge);
 		p.drawImage(0, 0, star);
 	}, badge->lifetime());
@@ -112,7 +115,7 @@ void AddPremiumStar(
 	rpl::combine(
 		button->sizeValue(),
 		std::move(label)
-	) | rpl::start_with_next([=](const QSize &s, const QString &) {
+	) | rpl::on_next([=](const QSize &s, const QString &) {
 		if (s.isNull()) {
 			return;
 		}
@@ -270,7 +273,7 @@ void AddPremiumPrivacyButton(
 		state->widget.paintRequest(
 		) | rpl::filter([=]() -> bool {
 			return state->widget.x();
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			auto p = QPainter(&state->widget);
 			st::settingsPremiumLock.paint(p, 0, 0, state->widget.width());
 		}, state->widget.lifetime());
@@ -280,7 +283,7 @@ void AddPremiumPrivacyButton(
 			std::move(label),
 			PrivacyString(session, key),
 			Data::AmPremiumValue(session)
-		) | rpl::start_with_next([=, &st](
+		) | rpl::on_next([=, &st](
 				const QSize &buttonSize,
 				const QString &button,
 				const QString &text,
@@ -308,15 +311,15 @@ void AddPremiumPrivacyButton(
 	}
 
 	const auto showToast = [=] {
-		auto link = Ui::Text::Link(
-			Ui::Text::Semibold(
+		auto link = tr::link(
+			tr::semibold(
 				tr::lng_settings_privacy_premium_link(tr::now)));
 		(*toast) = controller->showToast({
 			.text = tr::lng_settings_privacy_premium(
 				tr::now,
 				lt_link,
 				link,
-				Ui::Text::WithEntities),
+				tr::marked),
 			.duration = Ui::Toast::kDefaultDuration * 2,
 			.filter = crl::guard(&controller->session(), [=](
 					const ClickHandlerPtr &,
@@ -344,7 +347,7 @@ void AddPremiumPrivacyButton(
 			key
 		) | rpl::take(
 			1
-		) | rpl::start_with_next([=](const Privacy::Rule &value) {
+		) | rpl::on_next([=](const Privacy::Rule &value) {
 			controller->show(Box<EditPrivacyBox>(
 				controller,
 				controllerFactory(),
@@ -545,7 +548,7 @@ void SetupCloudPassword(
 		tr::lng_settings_cloud_password_start_title(),
 		std::move(label),
 		st::settingsButton,
-		{ &st::menuIconPermissions }
+		{ &st::menuIcon2SV }
 	)->addClickHandler([=, passwordState = base::duplicate(passwordState)] {
 		const auto state = rpl::variable<PasswordState>(
 			base::duplicate(passwordState)).current();
@@ -574,6 +577,63 @@ void SetupCloudPassword(
 	session->api().cloudPassword().reload();
 }
 
+void SetupPasskeys(
+		not_null<Window::SessionController*> controller,
+		not_null<Ui::VerticalLayout*> container) {
+	const auto session = &controller->session();
+	if (!session->passkeys().possible()) {
+		return;
+	}
+	const auto wrap = container->add(
+		object_ptr<Ui::SlideWrap<Ui::VerticalLayout>>(
+			container,
+			object_ptr<Ui::VerticalLayout>(container)));
+	auto label = rpl::combine(
+		tr::lng_profile_loading(),
+		(rpl::single(rpl::empty_value())
+			| rpl::then(session->passkeys().requestList())) | rpl::map([=] {
+			return session->passkeys().list().size();
+		})
+	) | rpl::map([=](const QString &loading, int count) {
+		return !session->passkeys().listKnown()
+			? loading
+			: count
+			? QString::number(count)
+			: tr::lng_settings_cloud_password_off(tr::now);
+	});
+	AddButtonWithLabel(
+		wrap->entity(),
+		tr::lng_settings_passkeys_title(),
+		std::move(label),
+		st::settingsButton,
+		{ &st::menuIconPermissions }
+	)->addClickHandler([=] {
+		if (!session->passkeys().listKnown()) {
+			return;
+		}
+		const auto count = session->passkeys().list().size();
+		if (count == 0) {
+			controller->show(Box([=](not_null<Ui::GenericBox*> box) {
+				PasskeysNoneBox(box, session);
+				box->boxClosing() | rpl::on_next([=] {
+					if (session->passkeys().list().size()) {
+						controller->showSettings(PasskeysId());
+					}
+				}, box->lifetime());
+			}));
+		} else {
+			controller->showSettings(PasskeysId());
+		}
+	});
+	wrap->toggleOn(
+		(rpl::single(rpl::empty_value())
+			| rpl::then(session->passkeys().requestList())) | rpl::map([=] {
+			return Platform::WebAuthn::IsSupported()
+				|| !session->passkeys().list().empty();
+		}));
+	wrap->finishAnimating();
+}
+
 void SetupLoginEmail(
 		not_null<Window::SessionController*> controller,
 		not_null<Ui::VerticalLayout*> container,
@@ -648,7 +708,7 @@ void SetupTopPeers(
 	}))->toggledChanges(
 	) | rpl::filter([=](bool enabled) {
 		return enabled == session->topPeers().disabled();
-	}) | rpl::start_with_next([=](bool enabled) {
+	}) | rpl::on_next([=](bool enabled) {
 		session->topPeers().toggleDisabled(!enabled);
 	}, container->lifetime());
 
@@ -667,7 +727,7 @@ void SetupSelfDestruction(
 
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().selfDestruct().reload();
 	}, container->lifetime());
 	const auto label = [&] {
@@ -814,7 +874,7 @@ void SetupBlockedList(
 	});
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().blockedPeers().reload();
 	}, blockedPeers->lifetime());
 }
@@ -826,7 +886,7 @@ void SetupWebsitesList(
 		Fn<void(Type)> showOther) {
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		controller->session().api().websites().reload();
 	}, container->lifetime());
 
@@ -864,7 +924,7 @@ void SetupSessionsList(
 		Fn<void(Type)> showOther) {
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		controller->session().api().authorizations().reload();
 	}, container->lifetime());
 
@@ -910,7 +970,7 @@ void SetupGlobalTTLList(
 	});
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().selfDestruct().reload();
 	}, container->lifetime());
 }
@@ -930,6 +990,7 @@ void SetupSecurity(
 		rpl::duplicate(updateTrigger),
 		showOther);
 	SetupLocalPasscode(controller, container, showOther);
+	SetupPasskeys(controller, container);
 	SetupLoginEmail(controller, container, showOther);
 	SetupBlockedList(
 		controller,
@@ -971,7 +1032,7 @@ void SetupSensitiveContent(
 
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().sensitiveContent().reload();
 	}, container->lifetime());
 	inner->add(object_ptr<Button>(
@@ -984,7 +1045,7 @@ void SetupSensitiveContent(
 	))->toggledChanges(
 	) | rpl::filter([=](bool toggled) {
 		return toggled != session->api().sensitiveContent().enabledCurrent();
-	}) | rpl::start_with_next([=](bool toggled) {
+	}) | rpl::on_next([=](bool toggled) {
 		if (toggled && session->appConfig().ageVerifyNeeded()) {
 			disable->fire({});
 
@@ -1034,12 +1095,12 @@ object_ptr<Ui::BoxContent> EditCloudPasswordBox(not_null<Main::Session*> session
 	rpl::merge(
 		box->newPasswordSet() | rpl::to_empty,
 		box->passwordReloadNeeded()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().reload();
 	}, box->lifetime());
 
 	box->clearUnconfirmedPassword(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().clearUnconfirmedPassword();
 	}, box->lifetime());
 
@@ -1062,12 +1123,12 @@ void RemoveCloudPassword(not_null<Window::SessionController*> controller) {
 	rpl::merge(
 		box->newPasswordSet() | rpl::to_empty,
 		box->passwordReloadNeeded()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().reload();
 	}, box->lifetime());
 
 	box->clearUnconfirmedPassword(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().clearUnconfirmedPassword();
 	}, box->lifetime());
 
@@ -1107,7 +1168,7 @@ not_null<Ui::SettingsButton*> AddPrivacyButton(
 			key
 		) | rpl::take(
 			1
-		) | rpl::start_with_next([=](const Privacy::Rule &value) {
+		) | rpl::on_next([=](const Privacy::Rule &value) {
 			controller->show(Box<EditPrivacyBox>(
 				controller,
 				controllerFactory(),
@@ -1144,7 +1205,7 @@ void SetupArchiveAndMute(
 	)->toggledChanges(
 	) | rpl::filter([=](bool toggled) {
 		return toggled != privacy->archiveAndMuteCurrent();
-	}) | rpl::start_with_next([=](bool toggled) {
+	}) | rpl::on_next([=](bool toggled) {
 		privacy->updateArchiveAndMute(toggled);
 	}, container->lifetime());
 
