@@ -83,7 +83,7 @@ void CameraBox(
 		return;
 	}
 	track->stateValue(
-	) | rpl::start_with_next([=](const VideoState &state) {
+	) | rpl::on_next([=](const VideoState &state) {
 		if (state == VideoState::Inactive) {
 			box->closeBox();
 		}
@@ -139,7 +139,7 @@ void SetupSubButtonBackground(
 
 	background->resize(size);
 	background->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(background);
 		auto hq = PainterHighQualityEnabler(p);
 		p.setBrush(st::boxBg);
@@ -148,7 +148,7 @@ void SetupSubButtonBackground(
 	}, background->lifetime());
 
 	upload->positionValue(
-	) | rpl::start_with_next([=](QPoint position) {
+	) | rpl::on_next([=](QPoint position) {
 		background->move(position - QPoint(border, border));
 	}, background->lifetime());
 }
@@ -231,7 +231,7 @@ void UserpicButton::prepare() {
 
 void UserpicButton::showCustomOnChosen() {
 	chosenImages(
-	) | rpl::start_with_next([=](ChosenImage &&chosen) {
+	) | rpl::on_next([=](ChosenImage &&chosen) {
 		showCustom(std::move(chosen.image));
 	}, lifetime());
 }
@@ -310,8 +310,8 @@ void UserpicButton::choosePhotoLocally() {
 				? (*phrase)(
 					tr::now,
 					lt_user,
-					Ui::Text::Bold(name),
-					Ui::Text::WithEntities)
+					tr::bold(name),
+					tr::marked)
 				: TextWithEntities()),
 			.confirm = ((type == ChosenType::Suggest)
 				? tr::lng_profile_suggest_button(tr::now)
@@ -430,7 +430,7 @@ void UserpicButton::choosePhotoLocally() {
 					key
 				) | rpl::take(
 					1
-				) | rpl::start_with_next([=](const UserPrivacy::Rule &value) {
+				) | rpl::on_next([=](const UserPrivacy::Rule &value) {
 					using namespace Settings;
 					_window->show(Box<EditPrivacyBox>(
 						_window->sessionController(),
@@ -505,7 +505,7 @@ void UserpicButton::setupPeerViewers() {
 				user->hasPersonalPhoto());
 		}) | rpl::distinct_until_changed() | rpl::skip(
 			1
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			processNewPeerPhoto();
 			update();
 		}, _sourceLifetime);
@@ -516,7 +516,7 @@ void UserpicButton::setupPeerViewers() {
 		_peer->session().changes().peerUpdates(
 			_peer,
 			Data::PeerUpdate::Flag::Photo
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			processNewPeerPhoto();
 			update();
 		}, _sourceLifetime);
@@ -524,7 +524,7 @@ void UserpicButton::setupPeerViewers() {
 	_peer->session().downloaderTaskFinished(
 	) | rpl::filter([=] {
 		return _waiting;
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		const auto loading = _showPeerUserpic
 			? Ui::PeerUserpicLoading(_userpicView)
 			: (_nonPersonalView && !_nonPersonalView->loaded());
@@ -789,7 +789,7 @@ bool UserpicButton::createStreamingObjects(not_null<PhotoData*> photo) {
 		nullptr);
 	_streamed->lockPlayer();
 	_streamed->player().updates(
-	) | rpl::start_with_next_error([=](Update &&update) {
+	) | rpl::on_next_error([=](Update &&update) {
 		handleStreamingUpdate(std::move(update));
 	}, [=](Error &&error) {
 		handleStreamingError(std::move(error));
@@ -969,7 +969,7 @@ void UserpicButton::switchChangePhotoOverlay(
 			updateCursorInChangeOverlay(
 				mapFromGlobal(QCursor::pos()));
 			if (chosen) {
-				chosenImages() | rpl::start_with_next(chosen, lifetime());
+				chosenImages() | rpl::on_next(chosen, lifetime());
 			}
 		} else {
 			_changeOverlayShown.stop();
