@@ -9,6 +9,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 namespace Data {
 struct UniqueGift;
+struct UniqueGiftBackdrop;
 } // namespace Data
 
 namespace Ui::Text {
@@ -29,6 +30,10 @@ struct PatternPoint {
 	QSize size,
 	const Data::UniqueGift &gift);
 
+[[nodiscard]] QImage CreateTopBgGradient(
+	QSize size,
+	const Data::UniqueGiftBackdrop &backdrop);
+
 [[nodiscard]] QImage CreateTopBgGradient(
 	QSize size,
 	QColor centerColor,
@@ -53,6 +58,15 @@ void PaintBgPoints(
 	const QRect &rect,
 	float64 shown = 1.);
 
+void PaintBgPoints(
+	QPainter &p,
+	const std::vector<PatternPoint> &points,
+	base::flat_map<float64, QImage> &cache,
+	not_null<Ui::Text::CustomEmoji*> emoji,
+	const Data::UniqueGiftBackdrop &backdrop,
+	const QRect &rect,
+	float64 shown = 1.);
+
 void PaintBgPoints(
 	QPainter &p,
 	const std::vector<PatternPoint> &points,
@@ -60,6 +74,6 @@ void PaintBgPoints(
 	not_null<Ui::Text::CustomEmoji*> emoji,
 	const QColor &patternColor,
 	const QRect &rect,
-	float64 shown);
+	float64 shown = 1.);
 
 } // namespace Ui
